#### Code used for analysis of LC/MS lipidomics data in:
#### Manuscript: Early life infection and proinflammatory, atherogenic metabolomic and lipidomic profiles at 12 months of age: a population-based cohort study
#### Authors: Toby Mansell, Richard Saffery, Satvika Burugupalli, Anne-Louise Ponsonby, Mimi LK Tang, Martin O'Hely, Siroon Bekkering, Adam AT Smith, Rebecca Rowland, Sarath Ranganathan, Peter D Sly, Peter Vuillermin, Fiona Collier, Peter J Meikle, David P Burgner, on behalf of the Barwon Infant Study Investigator Group

#### Code based on: Vignettes for the ggforestplot package authored by Scheinin et al., provided by Nightingale Health
#### Code adapted and modified by: Toby Mansell
#### Last edited: Mar 31st, 2022

#### Generates: Figure 5 and associated figure supplements and source data, Figure 6 and associated figure supplements and source data, Supp. Files 1D-F and 3B and 3D, and lipidomics data for Figure 7 and its associated figure supplement and source data
#### Note: the source data generated by this code was used to create Figure 5-figure supplement 1 and Figure 6-figure supplement 2 with an Excel template. This template was created by the Metabolomics lab at Baker IDI. Please contact Peter Meikle if you wish to access this template.

#### Required for code: lipid_name_conversation.csv, a datasheet assigning each lipid variable to a lipid subclass. This is available upon request, or can be substituted for any dataset with 3 variables: one ('biomarkerid') for the variable names in your data, one ('name') for their corresponding name to be output to tables, and one ('group') for their corresponding lipid subclass. 
#### For data access: Data is available upon reasonable request by bona fide researchers, with approval from BIS data custodians. Please contact the corresponding author for more details.

#### Note on computation: Bootstrap estimates are computationally intensive. Consider skipping these steps if computing cluster is not available.




library(tidyverse)
library(devtools)
library(ggforestplot)

set.seed(12345)

## Set working directory as appropriate
setwd("")

#### Reading in data ####


# Read the biomarker concentration file
df_nmr_results <- readr::read_csv(
  # Enter the correct location for your file below
  file = "Data/BIS_infection_dataset_LCMS.csv",
  # Set not only NA but TAG string as <NA> 
  na = c("NA", "TAG")
)


df_nmr_results_12m <- df_nmr_results[(df_nmr_results$timepoint=="12 months"),]

df_nmr_results_alt_names <- df_nmr_results_12m

nmr_biomarkers <- names(df_nmr_results_alt_names %>% select("Sph(d16:1)":"total_OxSpecies"))
nmr_biomarkers_6m <- names(df_nmr_results_alt_names %>% select("Sph(d16:1)_6m":"total_OxSpecies_6m"))


### Lipidomic measures have their minimum non-zero value added to them to allow for log-transformation of measures include zero values.
LSMC.minimumvalues <- data.frame(metabolite=character(),
                                minimum=double(),
                                stringsAsFactors=FALSE) 
holder <- LSMC.minimumvalues

for(i in nmr_biomarkers){
  
  holder[1,1] <- paste(i)
  holder[1,2] <- min(df_nmr_results_alt_names[[i]][!!df_nmr_results_alt_names[[i]]], na.rm=TRUE)
  
  LSMC.minimumvalues <- rbind(LSMC.minimumvalues, holder)
  df_nmr_results_alt_names[[i]] <- df_nmr_results_alt_names[[i]]+holder[1,2]
  
}

LSMC.minimumvalues <- data.frame(metabolite=character(),
                                minimum=double(),
                                stringsAsFactors=FALSE) 
holder <- LSMC.minimumvalues

for(i in nmr_biomarkers_6m){
  
  holder[1,1] <- paste(i)
  holder[1,2] <- min(df_nmr_results_alt_names[[i]][!!df_nmr_results_alt_names[[i]]], na.rm=TRUE)
  
  LSMC.minimumvalues <- rbind(LSMC.minimumvalues, holder)
  df_nmr_results_alt_names[[i]] <- df_nmr_results_alt_names[[i]]+holder[1,2]
}

marker_names <- read_csv("lipid_name_conversion.csv")


####### Regression models for primary models ############

### Creation of frame for caluclating correlation of estimated effects for number of infections, GlycA, and hsCRP - Figure 5C, 6B, 6C
beta.comparison.MS <- data.frame(metabolite=character(815),
                                 infection.beta=double(815),
                                 glyca.beta=double(815),
                                 hscrp.beta=double(815),
                                 stringsAsFactors=FALSE) 

########### Infection as exposure - Source data for Figure 5 ########


# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, anyinfection4wk12mo, age_interview_m12, sex, z_scores_birth, gestage, hhincome, bfany, mth12collectiontostorage, anympsmoke) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log1p(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ anyinfection4wk12mo + age_interview_m12 + sex + z_scores_birth + gestage + hhincome + bfany + mth12collectiontostorage + anympsmoke
      ),
    key = biomarkerid,
    predictor = anyinfection4wk12mo
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

beta.comparison.MS$metabolite <- df_assoc_per_biomarker$biomarkerid
beta.comparison.MS$infection.beta <- df_assoc_per_biomarker$estimate

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


ggplot_multi <-
  df_linear %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue,
        psignif = 0.05,
        xlab = "Difference in 12-month log lipids (SD units) for each infection from birth to 12 months",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.1, 0.1)) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8))
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = ggplot_multi$rel_heights
)

ggsave("Figures/BIS_eLife_Fig5A.png", width=4, height=6)


df_linear$model <- "Primary model"
figure_infection_base <- df_linear

df_linear$model <- "Household income"
figure_infection_hhincome <- df_linear

df_assoc_per_biomarker_totalsonly <- df_assoc_per_biomarker[777:815,]
df_assoc_per_biomarker_species <- df_assoc_per_biomarker[1:776,]
df_assoc_per_biomarker_species$pvalue_adj <- p.adjust(df_assoc_per_biomarker_species$pvalue, method = "BH")
df_assoc_per_biomarker_totalsonly$pvalue_adj <- p.adjust(df_assoc_per_biomarker_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_combinedplot <- rbind(df_assoc_per_biomarker_species, df_assoc_per_biomarker_totalsonly)

lipid_results <- df_assoc_per_biomarker_combinedplot

lipid_results$coef <- lipid_results$estimate
lipid_results$coef_lower <- lipid_results$estimate - (1.96 * lipid_results$se)
lipid_results$coef_upper <- lipid_results$estimate + (1.96 * lipid_results$se)
lipid_results$pval <- lipid_results$pvalue
lipid_results$qval <- lipid_results$pvalue_adj

lipid_results <- as.data.frame(lipid_results[,c(1,6:10)])  

write.csv(lipid_results,"BIS_eLife_Figure5_SourceData1A.csv")



###### Bootstrapping - NOTE: computationally intensive
df_nmr_results_alt_names_infection <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$anyinfection4wk12mo),]


library(boot)

set.seed(12345)


bootstrap_bca_cis <-  data.frame(biomarkerid=character(),
                                 estimate=double(),
                                 l.ci=double(),
                                 u.ci=double(),
                                 stringsAsFactors=FALSE)
regression <- bootstrap_bca_cis

for(i in nmr_biomarkers){
  
  df_nmr_results_alt_names_infection[[i]] <- log1p(df_nmr_results_alt_names_infection[[i]])
  df_nmr_results_alt_names_infection[[i]] <- as.numeric(scale(df_nmr_results_alt_names_infection[[i]]))
  
  boot.huber <- function(data, indices, maxit=20){
    data <- data[indices,] # select obs. in bootstrap sample
    mod <- lm(as.formula(paste("`",i,"` ~ anyinfection4wk12mo + age_interview_m12 + sex + z_scores_birth + gestage + hhincome + bfany + mth12collectiontostorage + anympsmoke", sep = "")), data=data, maxit=maxit)
    coefficients(mod) # return coefficient vector
  }
  
  
  duncan.boot <- boot(df_nmr_results_alt_names_infection, boot.huber, 1000, maxit=100)

  ci_boot_bca <- boot.ci(duncan.boot, index=2, type="bca")
  
  regression[1,1] <- paste(i)
  regression[1,2] <- mean(duncan.boot$t[,2])
  regression[1,3] <- ci_boot_bca$bca[4]
  regression[1,4] <- ci_boot_bca$bca[5]
  
  bootstrap_bca_cis <- rbind(bootstrap_bca_cis, regression)
  
}

bootstrap_infection_lipids_bfany <- bootstrap_bca_cis
write.csv(bootstrap_infection_lipids_bfany, "BIS_eLife_Figure5_SourceData1A_bootstrap.csv")

######## Several secondary analyses (comparing SEP measures and various sensitivity analyses) - Supp. File 1D #######
##### SEIFA

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, anyinfection4wk12mo, age_interview_m12, gender, z_scores_birth, seifa_disad, bfany, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ anyinfection4wk12mo + age_interview_m12 + gender + z_scores_birth + seifa_disad + bfany + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = anyinfection4wk12mo
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <- "SEIFA (area disadvantage)"
figure_infection_seifa <- df_linear



##### Maternal education

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, anyinfection4wk12mo, age_interview_m12, gender, z_scores_birth, meducation_t1t2_d, bfany, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ anyinfection4wk12mo + age_interview_m12 + gender + z_scores_birth + meducation_t1t2_d + bfany + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = anyinfection4wk12mo
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]


df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <- "Maternal education"
figure_infection_meducation <- df_linear



##### 2ndary covariate model

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, anyinfection4wk12mo, age_interview_m12, gender, z_scores_birth, hhincome, bfany, mth12collectiontostorage, anympsmoke, gestage, smokeinroom_bto12m, GDMnew, preeclampsia_yn) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ anyinfection4wk12mo + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage + smokeinroom_bto12m + GDMnew + preeclampsia_yn
      ),
    key = biomarkerid,
    predictor = anyinfection4wk12mo
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]


df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <-  "Primary model + additonal exposures"
figure_infection_secondary <- df_linear


##### Breastfeeding duration

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, anyinfection4wk12mo, age_interview_m12, gender, z_scores_birth, hhincome, bftomax52wks, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ anyinfection4wk12mo + age_interview_m12 + gender + z_scores_birth + hhincome + bftomax52wks + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = anyinfection4wk12mo
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]


df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <-  "Primary model with breastfeeding duration adjustment"
figure_infection_BFduration <- df_linear

##### Excluding active infection CRP>5

df_nmr_results_alt_names_hsCRPlessthan5 <- df_nmr_results_alt_names[(df_nmr_results_alt_names$hscrp<5),]

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_hsCRPlessthan5 %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, anyinfection4wk12mo, age_interview_m12, gender, z_scores_birth, hhincome, bfany, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ anyinfection4wk12mo + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = anyinfection4wk12mo
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <- "Primary model excluding hsCRP>5"
figure_infection_base_CRPexcl <- df_linear


##### Excluding twins

df_nmr_results_alt_names_notwins <- df_nmr_results_alt_names[!grepl('-1',df_nmr_results_alt_names$idchild),]
df_nmr_results_alt_names_notwins <- df_nmr_results_alt_names_notwins[!grepl('-2',df_nmr_results_alt_names_notwins$idchild),]

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_notwins %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, anyinfection4wk12mo, age_interview_m12, gender, z_scores_birth, hhincome, bfany, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ anyinfection4wk12mo + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = anyinfection4wk12mo
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <- "Primary model excluding twins"
figure_infection_base_twinsexcl <- df_linear



############# Processing time of <=4hr

df_nmr_results_alt_names_4hr <- df_nmr_results_alt_names[(df_nmr_results_alt_names$mth12collectiontostorage<=0.16666),]



# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_4hr %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, anyinfection4wk12mo, age_interview_m12, gender, z_scores_birth, hhincome, bfany, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ anyinfection4wk12mo + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = anyinfection4wk12mo
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)

df_linear$model <- "Primary model excluding >4hr blood processing time"
figure_infection_base_4hrprocessing <- df_linear


##### Combination figure - sensitivity- Supp File 1D (a)

df_linear <- rbind(figure_infection_base, figure_infection_secondary, figure_infection_base_CRPexcl, figure_infection_base_twinsexcl, figure_infection_base_4hrprocessing, figure_infection_BFduration)


# Convert to factor for ordering
df_linear$model <- as.factor(df_linear$model)

# # Reorder factors to reverse order, so they appear in the correct order in the plot
df_linear$model = factor(df_linear$model,levels(df_linear$model)[c(6,3,4,5,2,1)])

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


ggplot_multi <-
  df_linear %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue,
        psignif = 0.05,
        colour = model,
        xlab = "Difference in 12-month log lipids (SD units) for each infection from birth to 12 months",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.1, 0.1)) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8))
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = ggplot_multi$rel_heights
)

ggsave("Figures/BIS_eLife_SuppFile1D_a.png", width=8, height=18)



##### Combination figure - SEP measures - Supp File 1D (b)

df_linear <- rbind(figure_infection_hhincome, figure_infection_seifa, figure_infection_meducation)


# Convert to factor for ordering
df_linear$model <- as.factor(df_linear$model)

# # Reorder factors to reverse order, so they appear in the correct order in the plot
df_linear$model = factor(df_linear$model,levels(df_linear$model)[c(3,2,1)])


df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


ggplot_multi <-
  df_linear %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue,
        psignif = 0.05,
        colour = model,
        xlab = "Difference in 12-month log lipids (SD units) for each infection from birth to 12 months",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.1, 0.1)) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8))
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = ggplot_multi$rel_heights
)

ggsave("Figures/BIS_eLife_SuppFile1A_b.png", width=7, height=12)



###### 6m to 12m infections, adjusted for 6m infections and lipids ######

beta.comparison.MS_6mto12m <- data.frame(metabolite=character(815),
                                         infection.beta=double(815),
                                         glyca.beta=double(815),
                                         hscrp.beta=double(815),
                                         stringsAsFactors=FALSE) 


proper_name_order <- df_assoc_per_biomarker_bmi$biomarkerid

df_nmr_results_alt_names_loop <- df_nmr_results_alt_names

results_6mto12m <-  data.frame(cleanedname=character(),
                               estimate=double(),
                               se=double(),
                               pvalue=double(),
                               stringsAsFactors=FALSE)

regression <- results_6mto12m

colnames(df_nmr_results_alt_names_loop) <- make.names(colnames(df_nmr_results_alt_names_loop), unique=TRUE)

nmr_biomarkers_clean <- names(df_nmr_results_alt_names_loop %>% select("Sph.d16.1.":"total_OxSpecies"))

for(i in nmr_biomarkers_clean){
  
  j <- paste0(i,"_6m")
  df_6mto12m_loop <- df_nmr_results_alt_names_loop[!is.na(df_nmr_results_alt_names_loop[[i]]),]
  df_6mto12m_loop[[i]] <- log(df_6mto12m_loop[[i]])   
  df_6mto12m_loop[[i]] <- as.numeric(scale(df_6mto12m_loop[[i]]))
  df_6mto12m_loop <- df_6mto12m_loop[!is.na(df_6mto12m_loop[[j]]),]
  df_6mto12m_loop[[j]] <- log(df_6mto12m_loop[[j]])   
  df_6mto12m_loop[[j]] <- as.numeric(scale(df_6mto12m_loop[[j]]))
  
  expData <- lm(paste0("`",i,"` ~ anyinfection9mo12mo + anyinfection4wk6mo + ",j," + age_interview_m12 + age_interview_m6 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + mth6CollectiontoStorage_hr + anympsmoke + gestage"), data = df_6mto12m_loop)
  
  regression[1,1] <- paste(i)
  regression[1,2] <- summary(expData)$coefficients[2,1]
  regression[1,3] <- summary(expData)$coefficients[2,2]
  regression[1,4] <- summary(expData)$coefficients[2,4]
  
  
  results_6mto12m <- rbind(results_6mto12m, regression)
}

df_assoc_per_biomarker_bmi <- results_6mto12m
df_assoc_per_biomarker_bmi$biomarkerid <- proper_name_order
df_assoc_per_biomarker_bmi <- df_assoc_per_biomarker_bmi[,c(5,2,3,4)]


df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

beta.comparison.MS_6mto12m$metabolite <- df_assoc_per_biomarker_bmi$biomarkerid
beta.comparison.MS_6mto12m$infection.beta <- df_assoc_per_biomarker_bmi$estimate

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


ggplot_multi <-
  df_linear %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue,
        psignif = 0.05,
        xlab = "Difference in 12-month log lipids (SD units) for each infection from 6 to 12 months,\nadjusted for infections from birth to 6 months and 6-month lipidomic measures",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.15, 0.15)) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8))
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = ggplot_multi$rel_heights
)

ggsave("Figures/BIS_eLife_Fig5_FigSupp3A.png", width=4, height=6)


df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]
df_assoc_per_biomarker_bmi_species <- df_assoc_per_biomarker_bmi[1:776,]
df_assoc_per_biomarker_bmi_species$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_species$pvalue, method = "BH")
df_assoc_per_biomarker_bmi_totalsonly$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_combinedplot <- rbind(df_assoc_per_biomarker_bmi_species, df_assoc_per_biomarker_bmi_totalsonly)

lipid_results <- df_assoc_per_biomarker_bmi_combinedplot

lipid_results$coef <- lipid_results$estimate
lipid_results$coef_lower <- lipid_results$estimate - (1.96 * lipid_results$se)
lipid_results$coef_upper <- lipid_results$estimate + (1.96 * lipid_results$se)
lipid_results$pval <- lipid_results$pvalue
lipid_results$qval <- lipid_results$pvalue_adj

lipid_results <- as.data.frame(lipid_results[,c(1,6:10)])  

write.csv(lipid_results,"BIS_eLife_Fig5_SourceData3A.csv")

###### Bootstrapping ############
df_nmr_results_alt_names_infection <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$anyinfection4wk12mo),]

library(boot)

set.seed(12345)


bootstrap_bca_cis <-  data.frame(biomarkerid=character(),
                                 estimate=double(),
                                 l.ci=double(),
                                 u.ci=double(),
                                 stringsAsFactors=FALSE)
regression <- bootstrap_bca_cis

for(i in nmr_biomarkers_clean){
  
  j <- paste0(i,"_6m")
  df_6mto12m_loop <- df_nmr_results_alt_names_loop[!is.na(df_nmr_results_alt_names_loop[[i]]),]
  df_6mto12m_loop[[i]] <- log(df_6mto12m_loop[[i]])   
  df_6mto12m_loop[[i]] <- as.numeric(scale(df_6mto12m_loop[[i]]))
  df_6mto12m_loop <- df_6mto12m_loop[!is.na(df_6mto12m_loop[[j]]),]
  df_6mto12m_loop[[j]] <- log(df_6mto12m_loop[[j]])   
  df_6mto12m_loop[[j]] <- as.numeric(scale(df_6mto12m_loop[[j]]))
  
  boot.huber <- function(data, indices, maxit=20){
    data <- data[indices,] # select obs. in bootstrap sample
    mod <- lm(as.formula(paste0("`",i,"` ~ anyinfection9mo12mo + anyinfection4wk6mo + ",j," + age_interview_m12 + age_interview_m6 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + mth6CollectiontoStorage_hr + anympsmoke + gestage")), data = data, maxit=maxit)
    coefficients(mod) # return coefficient vector
  }
  
  
  duncan.boot <- boot(df_6mto12m_loop, boot.huber, 1000, maxit=100)

  ci_boot_bca <- boot.ci(duncan.boot, index=2, type="bca")
  
  regression[1,1] <- paste(i)
  regression[1,2] <- mean(duncan.boot$t[,2])
  regression[1,3] <- ci_boot_bca$bca[4]
  regression[1,4] <- ci_boot_bca$bca[5]
  
  bootstrap_bca_cis <- rbind(bootstrap_bca_cis, regression)
  
}

BIS_bootstrap_6mto12minfection_12mlipid_R1 <- bootstrap_bca_cis
write.csv(BIS_bootstrap_6mto12minfection_12mlipid_R1, "BIS_eLife_Figure5_SourceData3A_bootstrap.csv")


########### Preparing inflammation exposure variables - Source data for Figure 3B and 4A ########


df_nmr_results_alt_names$gp <- df_nmr_results_alt_names$gp+min(df_nmr_results_alt_names$gp[!!df_nmr_results_alt_names$gp], na.rm=TRUE)

df_nmr_results_alt_names$gp <- log(df_nmr_results_alt_names$gp)
df_nmr_results_alt_names$gp <- as.numeric(scale(df_nmr_results_alt_names$gp))

df_nmr_results_alt_names$hscrp_natural <- df_nmr_results_alt_names$hscrp

df_nmr_results_alt_names$hscrp <- df_nmr_results_alt_names$hscrp+min(df_nmr_results_alt_names$hscrp[!!df_nmr_results_alt_names$hscrp], na.rm=TRUE)

df_nmr_results_alt_names$hscrp <- log(df_nmr_results_alt_names$hscrp)
df_nmr_results_alt_names$hscrp <- as.numeric(scale(df_nmr_results_alt_names$hscrp))


df_nmr_results_alt_names_trimmed <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$anyinfection4wk12mo), ]


#### GlycA as exposure - Figure 5B ######


# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_trimmed %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, gp, age_interview_m12, gender, z_scores_birth, hhincome, bfany, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ gp + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = gp
  ) 

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

beta.comparison.MS$glyca.beta <- df_assoc_per_biomarker_bmi$estimate

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


ggplot_multi <-
  df_linear %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue,
        psignif = 0.05,
        xlab = "Difference in 12-month log lipids per 1 SD higher 12-month log GlycA",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.5, 0.5)) +
        ggplot2::scale_shape_manual(
          values = c(22L),
          labels = c("GlycA")) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8)) +
        ggplot2::theme(legend.position = "none")
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = ggplot_multi$rel_heights
)

ggsave("Figures/BIS_eLife_Fig5B.png", width=4.5, height=6)


df_linear$model <- "Primary model"
figure_GlycA_base <- df_linear

df_linear$model <- "Household income"
figure_GlycA_hhincome <- df_linear


df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]
df_assoc_per_biomarker_bmi_species <- df_assoc_per_biomarker_bmi[1:776,]
df_assoc_per_biomarker_bmi_species$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_species$pvalue, method = "BH")
df_assoc_per_biomarker_bmi_totalsonly$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_combinedplot <- rbind(df_assoc_per_biomarker_bmi_species, df_assoc_per_biomarker_bmi_totalsonly)

lipid_results <- df_assoc_per_biomarker_bmi_combinedplot

lipid_results$coef <- lipid_results$estimate
lipid_results$coef_lower <- lipid_results$estimate - (1.96 * lipid_results$se)
lipid_results$coef_upper <- lipid_results$estimate + (1.96 * lipid_results$se)
lipid_results$pval <- lipid_results$pvalue
lipid_results$qval <- lipid_results$pvalue_adj

lipid_results <- as.data.frame(lipid_results[,c(1,6:10)])  

write.csv(lipid_results,"BIS_eLife_Figure5_SourceData1B.csv")



###### Bootstrapping ############
df_nmr_results_alt_names_infection <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$anyinfection4wk12mo),]


library(boot)

set.seed(12345)


bootstrap_bca_cis <-  data.frame(biomarkerid=character(),
                                 estimate=double(),
                                 l.ci=double(),
                                 u.ci=double(),
                                 stringsAsFactors=FALSE)
regression <- bootstrap_bca_cis

for(i in nmr_biomarkers){

  df_nmr_results_alt_names_infection[[i]] <- log(df_nmr_results_alt_names_infection[[i]])
  df_nmr_results_alt_names_infection[[i]] <- as.numeric(scale(df_nmr_results_alt_names_infection[[i]]))

  boot.huber <- function(data, indices, maxit=20){
    data <- data[indices,] # select obs. in bootstrap sample
    mod <- lm(as.formula(paste("`",i,"` ~ gp + age_interview_m12 + gender + z_scores_birth + gestage + hhincome + bfany + mth12collectiontostorage + anympsmoke", sep = "")), data=data, maxit=maxit)
    coefficients(mod) # return coefficient vector
  }


  duncan.boot <- boot(df_nmr_results_alt_names_infection, boot.huber, 1000, maxit=100)

  ci_boot_bca <- boot.ci(duncan.boot, index=2, type="bca")

  regression[1,1] <- paste(i)
  regression[1,2] <- mean(duncan.boot$t[,2])
  regression[1,3] <- ci_boot_bca$bca[4]
  regression[1,4] <- ci_boot_bca$bca[5]

  bootstrap_bca_cis <- rbind(bootstrap_bca_cis, regression)

}

bootstrap_GlycA_lipids_bfany <- bootstrap_bca_cis
write.csv(bootstrap_GlycA_lipids_bfany, "BIS_eLife_Figure5_SourceData1B_bootstrap.csv")

######## Several secondary analyses (comparing SEP measures and various sensitivity analyses) - Supp. File 1E #######
##### SEIFA

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_trimmed %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, gp, age_interview_m12, gender, z_scores_birth, seifa_disad, bfany, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ gp + age_interview_m12 + gender + z_scores_birth + seifa_disad + bfany + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = gp
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <- "SEIFA (area disadvantage)"
figure_GlycA_seifa <- df_linear

##### Maternal education

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_trimmed %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, gp, age_interview_m12, gender, z_scores_birth, meducation_t1t2_d, bfany, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ gp + age_interview_m12 + gender + z_scores_birth + meducation_t1t2_d + bfany + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = gp
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]


df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <- "Maternal education"
figure_GlycA_meducation <- df_linear



##### 2ndary exposure model

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_trimmed %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, gp, age_interview_m12, gender, z_scores_birth, hhincome, bfany, mth12collectiontostorage, anympsmoke, gestage, smokeinroom_bto12m, GDMnew, preeclampsia_yn) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ gp + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage + smokeinroom_bto12m + GDMnew + preeclampsia_yn
      ),
    key = biomarkerid,
    predictor = gp
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]


df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <-  "Primary model + additonal exposures"
figure_GlycA_secondary <- df_linear



##### Breastfeeding duration

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_trimmed %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, gp, age_interview_m12, gender, z_scores_birth, hhincome, bftomax52wks, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ gp + age_interview_m12 + gender + z_scores_birth + hhincome + bftomax52wks + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = gp
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]


df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <-  "Primary model with breastfeeding duration adjustment"
figure_GlycA_BFduration <- df_linear



##### Excluding active infection CRP>5

df_nmr_results_alt_names_hsCRPlessthan5 <- df_nmr_results_alt_names_trimmed[(df_nmr_results_alt_names_trimmed$hscrp_natural<5),]

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_hsCRPlessthan5 %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, gp, age_interview_m12, gender, z_scores_birth, hhincome, bfany, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ gp + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = gp
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <- "Primary model excluding hsCRP>5"
figure_GlycA_base_CRPexcl <- df_linear



##### Excluding twins

df_nmr_results_alt_names_notwins <- df_nmr_results_alt_names_trimmed[!grepl('-1',df_nmr_results_alt_names_trimmed$idchild),]
df_nmr_results_alt_names_notwins <- df_nmr_results_alt_names_notwins[!grepl('-2',df_nmr_results_alt_names_notwins$idchild),]

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_notwins %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, gp, age_interview_m12, gender, z_scores_birth, hhincome, bfany, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ gp + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = gp
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <- "Primary model excluding twins"
figure_GlycA_base_twinsexcl <- df_linear



############# Processing time of <=4hr

df_nmr_results_alt_names_4hr <- df_nmr_results_alt_names_trimmed[(df_nmr_results_alt_names_trimmed$mth12collectiontostorage<=0.16666),]



# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_trimmed %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, gp, age_interview_m12, gender, z_scores_birth, hhincome, bfany, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ gp + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = gp
  ) 

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)

df_linear$model <- "Primary model excluding >4hr blood processing time"
figure_GlycA_base_4hrprocessing <- df_linear

##### Combination figure - sensitivity - Supp File 1E (a)

df_linear <- rbind(figure_GlycA_base, figure_GlycA_secondary, figure_GlycA_base_CRPexcl, figure_GlycA_base_twinsexcl, figure_GlycA_base_4hrprocessing, figure_GlycA_BFduration)


# Convert to factor for ordering
df_linear$model <- as.factor(df_linear$model)

# # Reorder factors to reverse order, so they appear in the correct order in the plot
df_linear$model = factor(df_linear$model,levels(df_linear$model)[c(6,3,4,5,2,1)])


df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


ggplot_multi <-
  df_linear %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue,
        psignif = 0.05,
        colour = model,
        xlab = "Difference in 12-month log lipids (SD units)\nin infants per 1-SD higher 12-month log GlycA",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.5, 0.5)) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8))
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = ggplot_multi$rel_heights
)

ggsave("Figures/BIS_eLife_SuppFile1E_a.png", width=8, height=18)



##### Combination figure - SEP measures- Supp File 1E (b)



df_linear <- rbind(figure_GlycA_hhincome, figure_GlycA_seifa, figure_GlycA_meducation)


# Convert to factor for ordering
df_linear$model <- as.factor(df_linear$model)

# # Reorder factors to reverse order, so they appear in the correct order in the plot
df_linear$model = factor(df_linear$model,levels(df_linear$model)[c(3,2,1)])


df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


ggplot_multi <-
  df_linear %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue,
        psignif = 0.05,
        colour = model,
        xlab = "Difference in 12-month log lipids (SD units)\nin infants per 1-SD higher 12-month log GlycA",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.5, 0.5)) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8))
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = ggplot_multi$rel_heights
)

ggsave("Figures/BIS_eLife_SuppFile1E_b.png", width=7, height=12)



###### 12m GlycA, adjusted for 6m GlycA and lipids ######


df_nmr_results_alt_names_loop <- df_nmr_results_alt_names

results_6mto12m <-  data.frame(cleanedname=character(),
                               estimate=double(),
                               se=double(),
                               pvalue=double(),
                               stringsAsFactors=FALSE)

regression <- results_6mto12m

colnames(df_nmr_results_alt_names_loop) <- make.names(colnames(df_nmr_results_alt_names_loop), unique=TRUE)

nmr_biomarkers_clean <- names(df_nmr_results_alt_names_loop %>% select("Sph.d16.1.":"total_OxSpecies"))

for(i in nmr_biomarkers_clean){
  
  j <- paste0(i,"_6m")
  df_6mto12m_loop <- df_nmr_results_alt_names_loop[!is.na(df_nmr_results_alt_names_loop[[i]]),]
  df_6mto12m_loop[[i]] <- log(df_6mto12m_loop[[i]])   
  df_6mto12m_loop[[i]] <- as.numeric(scale(df_6mto12m_loop[[i]]))
  df_6mto12m_loop <- df_6mto12m_loop[!is.na(df_6mto12m_loop[[j]]),]
  df_6mto12m_loop[[j]] <- log(df_6mto12m_loop[[j]])   
  df_6mto12m_loop[[j]] <- as.numeric(scale(df_6mto12m_loop[[j]]))
  
  expData <- lm(paste0("`",i,"` ~ gp + GlycA_6m + ",j," + age_interview_m12 + age_interview_m6 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + mth6CollectiontoStorage_hr + anympsmoke + gestage"), data = df_6mto12m_loop)
  
  regression[1,1] <- paste(i)
  regression[1,2] <- summary(expData)$coefficients[2,1]
  regression[1,3] <- summary(expData)$coefficients[2,2]
  regression[1,4] <- summary(expData)$coefficients[2,4]
  
  
  results_6mto12m <- rbind(results_6mto12m, regression)
}

df_assoc_per_biomarker_bmi <- results_6mto12m
df_assoc_per_biomarker_bmi$biomarkerid <- proper_name_order
df_assoc_per_biomarker_bmi <- df_assoc_per_biomarker_bmi[,c(5,2,3,4)]


df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

beta.comparison.MS_6mto12m$glyca.beta <- df_assoc_per_biomarker_bmi$estimate

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


ggplot_multi <-
  df_linear %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue,
        psignif = 0.05,
        xlab = "Difference in 12-month log lipids (SD units) per 1 SD higher 12-month log GlycA,\nadjusted for 6-month GlycA and lipidomic measures",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.5, 0.5)) +
        ggplot2::scale_shape_manual(
          values = c(22L),
          labels = c("GlycA")) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8)) +
        ggplot2::theme(legend.position = "none")
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = ggplot_multi$rel_heights
)

ggsave("Figures/BIS_eLife_Fig5_FigSupp3B.png", width=4, height=6)




df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]
df_assoc_per_biomarker_bmi_species <- df_assoc_per_biomarker_bmi[1:776,]
df_assoc_per_biomarker_bmi_species$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_species$pvalue, method = "BH")
df_assoc_per_biomarker_bmi_totalsonly$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_combinedplot <- rbind(df_assoc_per_biomarker_bmi_species, df_assoc_per_biomarker_bmi_totalsonly)

lipid_results <- df_assoc_per_biomarker_bmi_combinedplot

lipid_results$coef <- lipid_results$estimate
lipid_results$coef_lower <- lipid_results$estimate - (1.96 * lipid_results$se)
lipid_results$coef_upper <- lipid_results$estimate + (1.96 * lipid_results$se)
lipid_results$pval <- lipid_results$pvalue
lipid_results$qval <- lipid_results$pvalue_adj

lipid_results <- as.data.frame(lipid_results[,c(1,6:10)])  

write.csv(lipid_results,"BIS_eLife_Fig5_SourceData3B.csv")

###### Bootstrapping ############
df_nmr_results_alt_names_infection <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$anyinfection4wk12mo),]

library(boot)

set.seed(12345)


bootstrap_bca_cis <-  data.frame(biomarkerid=character(),
                                 estimate=double(),
                                 l.ci=double(),
                                 u.ci=double(),
                                 stringsAsFactors=FALSE)
regression <- bootstrap_bca_cis

for(i in nmr_biomarkers_clean){
  
  j <- paste0(i,"_6m")
  df_6mto12m_loop <- df_nmr_results_alt_names_loop[!is.na(df_nmr_results_alt_names_loop[[i]]),]
  df_6mto12m_loop[[i]] <- log(df_6mto12m_loop[[i]])   
  df_6mto12m_loop[[i]] <- as.numeric(scale(df_6mto12m_loop[[i]]))
  df_6mto12m_loop <- df_6mto12m_loop[!is.na(df_6mto12m_loop[[j]]),]
  df_6mto12m_loop[[j]] <- log(df_6mto12m_loop[[j]])   
  df_6mto12m_loop[[j]] <- as.numeric(scale(df_6mto12m_loop[[j]]))
  
  boot.huber <- function(data, indices, maxit=20){
    data <- data[indices,] # select obs. in bootstrap sample
    mod <- lm(as.formula(paste0("`",i,"` ~ gp + GlycA_6m + ",j," + age_interview_m12 + age_interview_m6 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + mth6CollectiontoStorage_hr + anympsmoke + gestage")), data = data, maxit=maxit)
    coefficients(mod) # return coefficient vector
  }
  
  
  duncan.boot <- boot(df_6mto12m_loop, boot.huber, 1000, maxit=100)
  # plot(duncan.boot, index=2)
  
  #boot.ci(duncan.boot, index=2, type=c("norm", "perc", "bca"))
  ci_boot_bca <- boot.ci(duncan.boot, index=2, type="bca")
  
  regression[1,1] <- paste(i)
  regression[1,2] <- mean(duncan.boot$t[,2])
  regression[1,3] <- ci_boot_bca$bca[4]
  regression[1,4] <- ci_boot_bca$bca[5]
  
  bootstrap_bca_cis <- rbind(bootstrap_bca_cis, regression)
  
}

BIS_bootstrap_6mto12mGlycA_12mlipid_R1 <- bootstrap_bca_cis
write.csv(BIS_bootstrap_6mto12mGlycA_12mlipid_R1, "BIS_eLife_Figure5_SourceData3B_bootstrap.csv")



#### hsCRP as exposure - Source data for Figure 6 ######

df_nmr_results_alt_names_trimmed <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$anyinfection4wk12mo), ]


# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_trimmed %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, hscrp, age_interview_m12, gender, z_scores_birth, hhincome, bfany, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ hscrp + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = hscrp
  ) 

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

beta.comparison.MS$hscrp.beta <- df_assoc_per_biomarker_bmi$estimate

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


ggplot_multi <-
  df_linear %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue,
        psignif = 0.05,
        xlab = "Difference in 12-month log lipids per 1-SD increase in 12-month log hsCRP",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.5, 0.5)) +
        ggplot2::scale_shape_manual(
          values = c(23L),
          labels = c("hsCRP")) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8)) +
        ggplot2::theme(legend.position = "none")
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = ggplot_multi$rel_heights
)

ggsave("Figures/BIS_eLife_Fig6A.png", width=4.5, height=6)

df_linear$model <- "Primary model"
figure_hsCRP_base <- df_linear

df_linear$model <- "Household income"
figure_hsCRP_hhincome <- df_linear


df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]
df_assoc_per_biomarker_bmi_species <- df_assoc_per_biomarker_bmi[1:776,]
df_assoc_per_biomarker_bmi_species$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_species$pvalue, method = "BH")
df_assoc_per_biomarker_bmi_totalsonly$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_combinedplot <- rbind(df_assoc_per_biomarker_bmi_species, df_assoc_per_biomarker_bmi_totalsonly)

lipid_results <- df_assoc_per_biomarker_bmi_combinedplot

lipid_results$coef <- lipid_results$estimate
lipid_results$coef_lower <- lipid_results$estimate - (1.96 * lipid_results$se)
lipid_results$coef_upper <- lipid_results$estimate + (1.96 * lipid_results$se)
lipid_results$pval <- lipid_results$pvalue
lipid_results$qval <- lipid_results$pvalue_adj

lipid_results <- as.data.frame(lipid_results[,c(1,6:10)])  

write.csv(lipid_results,"BIS_eLife_Figure6_SourceData1.csv")




##### Bootstrapping ############
df_nmr_results_alt_names_infection <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$anyinfection4wk12mo),]


library(boot)

set.seed(12345)


bootstrap_bca_cis <-  data.frame(biomarkerid=character(),
                                 estimate=double(),
                                 l.ci=double(),
                                 u.ci=double(),
                                 stringsAsFactors=FALSE)
regression <- bootstrap_bca_cis

for(i in nmr_biomarkers){

  df_nmr_results_alt_names_infection[[i]] <- log(df_nmr_results_alt_names_infection[[i]])
  df_nmr_results_alt_names_infection[[i]] <- as.numeric(scale(df_nmr_results_alt_names_infection[[i]]))

  boot.huber <- function(data, indices, maxit=20){
    data <- data[indices,] # select obs. in bootstrap sample
    mod <- lm(as.formula(paste("`",i,"` ~ hscrp + age_interview_m12 + gender + z_scores_birth + gestage + hhincome + bfany + mth12collectiontostorage + anympsmoke", sep = "")), data=data, maxit=maxit)
    coefficients(mod) # return coefficient vector
  }


  duncan.boot <- boot(df_nmr_results_alt_names_infection, boot.huber, 1000, maxit=100)
  # plot(duncan.boot, index=2)

  #boot.ci(duncan.boot, index=2, type=c("norm", "perc", "bca"))
  ci_boot_bca <- boot.ci(duncan.boot, index=2, type="bca")

  regression[1,1] <- paste(i)
  regression[1,2] <- mean(duncan.boot$t[,2])
  regression[1,3] <- ci_boot_bca$bca[4]
  regression[1,4] <- ci_boot_bca$bca[5]

  bootstrap_bca_cis <- rbind(bootstrap_bca_cis, regression)

}

bootstrap_hsCRP_lipids_bfany <- bootstrap_bca_cis
write.csv(bootstrap_hsCRP_lipids_bfany, "BIS_eLife_Figure6_SourceData1_bootstrap.csv")

######## Several secondary analyses (comparing SEP measures and various sensitivity analyses) - Supp. File 1F #######
##### SEIFA

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_trimmed %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, hscrp, age_interview_m12, gender, z_scores_birth, seifa_disad, bfany, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ hscrp + age_interview_m12 + gender + z_scores_birth + seifa_disad + bfany + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = hscrp
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <- "SEIFA (area disadvantage)"
figure_hsCRP_seifa <- df_linear


##### Maternal education

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_trimmed %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, hscrp, age_interview_m12, gender, z_scores_birth, meducation_t1t2_d, bfany, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ hscrp + age_interview_m12 + gender + z_scores_birth + meducation_t1t2_d + bfany + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = hscrp
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]


df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <- "Maternal education"
figure_hsCRP_meducation <- df_linear


##### 2ndary exposure model

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_trimmed %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, hscrp, age_interview_m12, gender, z_scores_birth, hhincome, bfany, mth12collectiontostorage, anympsmoke, gestage, smokeinroom_bto12m, GDMnew, preeclampsia_yn) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ hscrp + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage + smokeinroom_bto12m + GDMnew + preeclampsia_yn
      ),
    key = biomarkerid,
    predictor = hscrp
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]


df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <-  "Primary model + additonal exposures"
figure_hsCRP_secondary <- df_linear


##### Breastfeeding duration

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_trimmed %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, hscrp, age_interview_m12, gender, z_scores_birth, hhincome, bftomax52wks, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ hscrp + age_interview_m12 + gender + z_scores_birth + hhincome + bftomax52wks + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = hscrp
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]


df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <-  "Primary model with breastfeeding duration adjustment"
figure_hsCRP_BFduration <- df_linear


##### Excluding active infection CRP>5

df_nmr_results_alt_names_hsCRPlessthan5 <- df_nmr_results_alt_names_trimmed[(df_nmr_results_alt_names_trimmed$hscrp_natural<5),]

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_hsCRPlessthan5 %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, hscrp, age_interview_m12, gender, z_scores_birth, hhincome, bfany, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ hscrp + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = hscrp
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <- "Primary model excluding hsCRP>5"
figure_hsCRP_base_CRPexcl <- df_linear



##### Excluding twins

df_nmr_results_alt_names_notwins <- df_nmr_results_alt_names_trimmed[!grepl('-1',df_nmr_results_alt_names_trimmed$idchild),]
df_nmr_results_alt_names_notwins <- df_nmr_results_alt_names_notwins[!grepl('-2',df_nmr_results_alt_names_notwins$idchild),]

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_notwins %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, hscrp, age_interview_m12, gender, z_scores_birth, hhincome, bfany, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ hscrp + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = hscrp
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <- "Primary model excluding twins"
figure_hsCRP_base_twinsexcl <- df_linear




############# Processing time of <=4hr

df_nmr_results_alt_names_4hr <- df_nmr_results_alt_names_trimmed[(df_nmr_results_alt_names_trimmed$mth12collectiontostorage<=0.16666),]



# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_4hr %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, hscrp, age_interview_m12, gender, z_scores_birth, hhincome, bfany, mth12collectiontostorage, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ hscrp + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = hscrp
  ) 

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


df_linear$model <- "Primary model excluding >4hr blood processing time"
figure_hsCRP_base_4hrprocessing <- df_linear


##### Combination figure - sensitivity- Supp File 1F (a)

df_linear <- rbind(figure_hsCRP_base, figure_hsCRP_secondary, figure_hsCRP_base_CRPexcl, figure_hsCRP_base_twinsexcl, figure_hsCRP_base_4hrprocessing, figure_hsCRP_BFduration)


# Convert to factor for ordering
df_linear$model <- as.factor(df_linear$model)

# # Reorder factors to reverse order, so they appear in the correct order in the plot
df_linear$model = factor(df_linear$model,levels(df_linear$model)[c(6,3,4,5,2,1)])


df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


ggplot_multi <-
  df_linear %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue,
        psignif = 0.05,
        colour = model,
        xlab = "Difference in 12-month log lipids (SD units)\nin infants per 1-SD higher 12-month log hsCRP",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.5, 0.5)) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8))
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = ggplot_multi$rel_heights
)

ggsave("Figures/BIS_eLife_SuppFile1F_a.png", width=8, height=18)



##### Combination figure - SEP measures- Supp File 1C (b)



df_linear <- rbind(figure_hsCRP_hhincome, figure_hsCRP_seifa, figure_hsCRP_meducation)


# Convert to factor for ordering
df_linear$model <- as.factor(df_linear$model)

# # Reorder factors to reverse order, so they appear in the correct order in the plot
df_linear$model = factor(df_linear$model,levels(df_linear$model)[c(3,2,1)])


df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


ggplot_multi <-
  df_linear %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue,
        psignif = 0.05,
        colour = model,
        xlab = "Difference in 12-month log lipids (SD units)\nin infants per 1-SD higher 12-month log hsCRP",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.5, 0.5)) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8))
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = ggplot_multi$rel_heights
)

ggsave("Figures/BIS_eLife_SuppFile1F_b.png", width=7, height=12)





###### 12m hsCRP, adjusted for 6m hsCRP and lipids ######


df_nmr_results_alt_names_loop <- df_nmr_results_alt_names

results_6mto12m <-  data.frame(cleanedname=character(),
                               estimate=double(),
                               se=double(),
                               pvalue=double(),
                               stringsAsFactors=FALSE)

regression <- results_6mto12m

colnames(df_nmr_results_alt_names_loop) <- make.names(colnames(df_nmr_results_alt_names_loop), unique=TRUE)

nmr_biomarkers_clean <- names(df_nmr_results_alt_names_loop %>% select("Sph.d16.1.":"total_OxSpecies"))

for(i in nmr_biomarkers_clean){
  
  j <- paste0(i,"_6m")
  df_6mto12m_loop <- df_nmr_results_alt_names_loop[!is.na(df_nmr_results_alt_names_loop[[i]]),]
  df_6mto12m_loop[[i]] <- log(df_6mto12m_loop[[i]])   
  df_6mto12m_loop[[i]] <- as.numeric(scale(df_6mto12m_loop[[i]]))
  df_6mto12m_loop <- df_6mto12m_loop[!is.na(df_6mto12m_loop[[j]]),]
  df_6mto12m_loop[[j]] <- log(df_6mto12m_loop[[j]])   
  df_6mto12m_loop[[j]] <- as.numeric(scale(df_6mto12m_loop[[j]]))
  
  expData <- lm(paste0("`",i,"` ~ hscrp + hsCRP_6m + ",j," + age_interview_m12 + age_interview_m6 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + mth6CollectiontoStorage_hr + anympsmoke + gestage"), data = df_6mto12m_loop)
  
  regression[1,1] <- paste(i)
  regression[1,2] <- summary(expData)$coefficients[2,1]
  regression[1,3] <- summary(expData)$coefficients[2,2]
  regression[1,4] <- summary(expData)$coefficients[2,4]
  
  
  results_6mto12m <- rbind(results_6mto12m, regression)
}

df_assoc_per_biomarker_bmi <- results_6mto12m
df_assoc_per_biomarker_bmi$biomarkerid <- proper_name_order
df_assoc_per_biomarker_bmi <- df_assoc_per_biomarker_bmi[,c(5,2,3,4)]


df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

beta.comparison.MS_6mto12m$hscrp.beta <- df_assoc_per_biomarker_bmi$estimate

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


ggplot_multi <-
  df_linear %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue,
        psignif = 0.05,
        xlab = "Difference in 12-month log lipids (SD units) per 1 SD higher 12-month log hsCRP,\nadjusted for 6-month hsCRP and lipidomic measures",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.5, 0.5)) +
        ggplot2::scale_shape_manual(
          values = c(23L),
          labels = c("hsCRP")) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8)) +
        ggplot2::theme(legend.position = "none")
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = ggplot_multi$rel_heights
)

ggsave("Figures/BIS_eLife_Fig6_FigSupp3A.png", width=4, height=6)



df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]
df_assoc_per_biomarker_bmi_species <- df_assoc_per_biomarker_bmi[1:776,]
df_assoc_per_biomarker_bmi_species$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_species$pvalue, method = "BH")
df_assoc_per_biomarker_bmi_totalsonly$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_combinedplot <- rbind(df_assoc_per_biomarker_bmi_species, df_assoc_per_biomarker_bmi_totalsonly)

lipid_results <- df_assoc_per_biomarker_bmi_combinedplot

lipid_results$coef <- lipid_results$estimate
lipid_results$coef_lower <- lipid_results$estimate - (1.96 * lipid_results$se)
lipid_results$coef_upper <- lipid_results$estimate + (1.96 * lipid_results$se)
lipid_results$pval <- lipid_results$pvalue
lipid_results$qval <- lipid_results$pvalue_adj

lipid_results <- as.data.frame(lipid_results[,c(1,6:10)])  

write.csv(lipid_results,"BIS_eLife_Fig6_SourceData3.csv")



###### Bootstrapping ############
df_nmr_results_alt_names_infection <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$anyinfection4wk12mo),]

library(boot)

set.seed(12345)


bootstrap_bca_cis <-  data.frame(biomarkerid=character(),
                                 estimate=double(),
                                 l.ci=double(),
                                 u.ci=double(),
                                 stringsAsFactors=FALSE)
regression <- bootstrap_bca_cis

for(i in nmr_biomarkers_clean){
  
  j <- paste0(i,"_6m")
  df_6mto12m_loop <- df_nmr_results_alt_names_loop[!is.na(df_nmr_results_alt_names_loop[[i]]),]
  df_6mto12m_loop[[i]] <- log(df_6mto12m_loop[[i]])   
  df_6mto12m_loop[[i]] <- as.numeric(scale(df_6mto12m_loop[[i]]))
  df_6mto12m_loop <- df_6mto12m_loop[!is.na(df_6mto12m_loop[[j]]),]
  df_6mto12m_loop[[j]] <- log(df_6mto12m_loop[[j]])   
  df_6mto12m_loop[[j]] <- as.numeric(scale(df_6mto12m_loop[[j]]))
  
  boot.huber <- function(data, indices, maxit=20){
    data <- data[indices,] # select obs. in bootstrap sample
    mod <- lm(as.formula(paste0("`",i,"` ~ hscrp + hsCRP_6m + ",j," + age_interview_m12 + age_interview_m6 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + mth6CollectiontoStorage_hr + anympsmoke + gestage")), data = data, maxit=maxit)
    coefficients(mod) # return coefficient vector
  }
  
  
  duncan.boot <- boot(df_6mto12m_loop, boot.huber, 1000, maxit=100)

  ci_boot_bca <- boot.ci(duncan.boot, index=2, type="bca")
  
  regression[1,1] <- paste(i)
  regression[1,2] <- mean(duncan.boot$t[,2])
  regression[1,3] <- ci_boot_bca$bca[4]
  regression[1,4] <- ci_boot_bca$bca[5]
  
  bootstrap_bca_cis <- rbind(bootstrap_bca_cis, regression)
  
}

BIS_bootstrap_6mto12mhsCRP_12mlipid_R1 <- bootstrap_bca_cis
write.csv(BIS_bootstrap_6mto12mhsCRP_12mlipid_R1, "BIS_eLife_Figure6_SourceData3_bootstrap.csv")



###### Scatterplot of lipidomic difference correlation - Figure 5C, 6B, 6C #####


# Add the regression line without the confidence interval
q <- ggplot(beta.comparison.MS, aes(x=infection.beta, y=glyca.beta)) +
  geom_point(shape=15, color="darkgrey")+
  geom_smooth(method=lm, se=FALSE, color="black")+
  theme_classic()+
  labs(x="Infection Beta (per 1 infection)", y = "GlycA Beta (per SD log GlycA)")

ggsave(plot = q, width = 3, height = 3, dpi = 600, filename = "Figures/BIS_eLife_Figure5C.png")

cor.test(beta.comparison.MS$infection.beta, beta.comparison.MS$glyca.beta)

q <- ggplot(beta.comparison.MS, aes(x=infection.beta, y=hscrp.beta)) +
  geom_point(shape=18, color="darkgrey")+
  geom_smooth(method=lm, se=FALSE, color="black")+
  theme_classic()+
  labs(x="Infection Beta (per 1 infection)", y = "hsCRP Beta (per SD log hsCRP)")

ggsave(plot = q, width = 3, height = 3, dpi = 600, filename = "Figures/BIS_eLife_Figure6B.png")


cor.test(beta.comparison.MS$infection.beta, beta.comparison.MS$hscrp.beta)


q <- ggplot(beta.comparison.MS, aes(x=glyca.beta, y=hscrp.beta)) +
  geom_point(shape=18, color="darkgrey")+
  geom_smooth(method=lm, se=FALSE, color="black")+
  theme_classic()+
  labs(x="GlycA Beta (per SD log GlycA)", y = "hsCRP Beta (per SD log hsCRP)")

ggsave(plot = q, width = 3, height = 3, dpi = 600, filename = "Figures/BIS_eLife_Figure6C.png")


cor.test(beta.comparison.MS$glyca.beta, beta.comparison.MS$hscrp.beta)




###### Scatterplot of lipidomic difference correlation - 6m to 12m - Figure 5-fig supp 3C, 6-fig supp 3B, 6-fig supp 3C #####


# Add the regression line without the confidence interval
q <- ggplot(beta.comparison.MS_6mto12m, aes(x=infection.beta, y=glyca.beta)) +
  geom_point(shape=15, color="darkgrey")+
  geom_smooth(method=lm, se=FALSE, color="black")+
  theme_classic()+
  labs(x="Infection Beta (per 1 infection)", y = "GlycA Beta (per SD log GlycA)")

ggsave(plot = q, width = 3, height = 3, dpi = 600, filename = "Figures/BIS_eLife_Figure5_FigSupp3C.png")

cor.test(beta.comparison.MS_6mto12m$infection.beta, beta.comparison.MS_6mto12m$glyca.beta)

q <- ggplot(beta.comparison.MS_6mto12m, aes(x=infection.beta, y=hscrp.beta)) +
  geom_point(shape=18, color="darkgrey")+
  geom_smooth(method=lm, se=FALSE, color="black")+
  theme_classic()+
  labs(x="Infection Beta (per 1 infection)", y = "hsCRP Beta (per SD log hsCRP)")

ggsave(plot = q, width = 3, height = 3, dpi = 600, filename = "Figures/BIS_eLife_Figure6_FigSupp3B.png")


cor.test(beta.comparison.MS_6mto12m$infection.beta, beta.comparison.MS_6mto12m$hscrp.beta)


q <- ggplot(beta.comparison.MS_6mto12m, aes(x=glyca.beta, y=hscrp.beta)) +
  geom_point(shape=18, color="darkgrey")+
  geom_smooth(method=lm, se=FALSE, color="black")+
  theme_classic()+
  labs(x="GlycA Beta (per SD log GlycA)", y = "hsCRP Beta (per SD log hsCRP)")

ggsave(plot = q, width = 3, height = 3, dpi = 600, filename = "Figures/BIS_eLife_Figure6_FigSupp3C.png")


cor.test(beta.comparison.MS_6mto12m$glyca.beta, beta.comparison.MS_6mto12m$hscrp.beta)





######### Lipidomics mediation - Fig 7 and associated figure supplement and Source Data ###############

library(medflex)

set.seed(12345)

mediation_effects <-  data.frame(mediator=character(),
                                 biomarkerid=character(),
                                 total_estimate=double(),
                                 total_se=double(),
                                 total_p=double(),
                                 direct_estimate=double(),
                                 direct_se=double(),
                                 direct_p=double(),
                                 indirect_estimate=double(),
                                 indirect_se=double(),
                                 indirect_p=double(),
                                 mediation=double(),
                                 model=character(),
                                 time=character(),
                                 stringsAsFactors=FALSE)
regression <- mediation_effects

df_mediation_data <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$gp),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$anyinfection4wk12mo),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$age_interview_m12),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$gender),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$z_scores_birth),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$hhincome),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$bfany),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$mth12collectiontostorage),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$anympsmoke),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$gestage),]

metabs <- c("total_DE", "total_C1P", "total_THC", "total_LPC_P", "total_PE_O", "total_PE_P", "total_CE", "HexCer(d18:2/18:0)", 
            "HexCer(d18:2/22:0)", "Hex3Cer(d18:1/18:0)", "Hex3Cer(d18:1/20:0)", "Hex3Cer(d18:1/22:0)", 
            "GM3(d18:1/18:0)", "DE(18:2)", "CE(22:6)", "HexCer(d16:1/24:0)", "PE(18:0_20:3) (a)")


for(i in metabs){
  
  
  df_mediation_loop <- df_mediation_data[!is.na(df_mediation_data[[i]]),]
  df_mediation_loop[[i]] <- log(df_mediation_loop[[i]])   
  df_mediation_loop[[i]] <- as.numeric(scale(df_mediation_loop[[i]]))
  
  expData <- neImpute(paste0("`",i,"` ~ anyinfection4wk12mo + gp + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage"), family = gaussian(link = "identity"), data = df_mediation_loop, nRep = 5)
  neMod1 <- neModel(paste0("`",i,"` ~ anyinfection4wk12mo0 + anyinfection4wk12mo1 + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage"), family = gaussian(link = "identity"), expData = expData, se = "robust")
  
  effdecomp <- neEffdecomp(neMod1)
  
  regression[1,1] <- "GlycA"
  regression[1,2] <- paste(i)
  regression[1,6] <- summary(effdecomp)[9]$test$coefficients[1]
  regression[1,9] <- summary(effdecomp)[9]$test$coefficients[2]
  regression[1,3] <- summary(effdecomp)[9]$test$coefficients[3]
  regression[1,7] <- summary(effdecomp)[9]$test$sigma[1]
  regression[1,10] <- summary(effdecomp)[9]$test$sigma[2]
  regression[1,4] <- summary(effdecomp)[9]$test$sigma[3]
  regression[1,8] <- summary(effdecomp)[9]$test$pvalues[1]
  regression[1,11] <- summary(effdecomp)[9]$test$pvalues[2]
  regression[1,5] <- summary(effdecomp)[9]$test$pvalues[3]
  regression[1,12] <- regression[1,9]/regression[1,3]
  regression[1,13] <- "Primary"
  regression[1,14] <- "Birth to 12m"
  
  mediation_effects <- rbind(mediation_effects, regression)
}

mediation_effects_primary_bto12m_GlycA <- mediation_effects


######### Metabolomics mediation - 6m to 12m


mediation_effects <-  data.frame(mediator=character(),
                                 biomarkerid=character(),
                                 total_estimate=double(),
                                 total_se=double(),
                                 total_p=double(),
                                 direct_estimate=double(),
                                 direct_se=double(),
                                 direct_p=double(),
                                 indirect_estimate=double(),
                                 indirect_se=double(),
                                 indirect_p=double(),
                                 mediation=double(),
                                 model=character(),
                                 time=character(),
                                 stringsAsFactors=FALSE)
regression <- mediation_effects

df_mediation_data_6mto12m <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$gp),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$anyinfection4wk12mo),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$age_interview_m12),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$gender),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$z_scores_birth),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$hhincome),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$bfany),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$mth12collectiontostorage),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$anympsmoke),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$gestage),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$anyinfection4wk6mo),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$anyinfection9mo12mo),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$GlycA_6m),]

colnames(df_mediation_data_6mto12m) <- make.names(colnames(df_mediation_data_6mto12m), unique=TRUE)

metabs <- c("total_DE", "total_C1P", "total_THC", "total_LPC_P", "total_PE_O", "total_PE_P", "total_CE", "HexCer.d18.2.18.0.", 
            "HexCer.d18.2.22.0.", "Hex3Cer.d18.1.18.0.", "Hex3Cer.d18.1.20.0.", "Hex3Cer.d18.1.22.0.", 
            "GM3.d18.1.18.0.", "DE.18.2.", "CE.22.6.", "HexCer.d16.1.24.0.", "PE.18.0_20.3...a.")

for(i in metabs){
  
  j <- paste0(i,"_6m")
  df_mediation_loop <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m[[i]]),]
  df_mediation_loop[[i]] <- log(df_mediation_loop[[i]])   
  df_mediation_loop[[i]] <- as.numeric(scale(df_mediation_loop[[i]]))
  df_mediation_loop <- df_mediation_loop[!is.na(df_mediation_loop[[j]]),]
  df_mediation_loop[[j]] <- log(df_mediation_loop[[j]])   
  df_mediation_loop[[j]] <- as.numeric(scale(df_mediation_loop[[j]]))
  
  expData <- neImpute(paste0("`",i,"` ~ anyinfection9mo12mo + gp + anyinfection4wk6mo + GlycA_6m + ",j," + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage"), family = gaussian(link = "identity"), data = df_mediation_loop, nRep = 5)
  neMod1 <- neModel(paste0("`",i,"` ~ anyinfection9mo12mo0 + anyinfection9mo12mo1 + anyinfection4wk6mo + GlycA_6m + ",j," + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage"), family = gaussian(link = "identity"), expData = expData, se = "robust")
  
  effdecomp <- neEffdecomp(neMod1)
  
  regression[1,1] <- "GlycA"
  regression[1,2] <- paste(i)
  regression[1,6] <- summary(effdecomp)[9]$test$coefficients[1]
  regression[1,9] <- summary(effdecomp)[9]$test$coefficients[2]
  regression[1,3] <- summary(effdecomp)[9]$test$coefficients[3]
  regression[1,7] <- summary(effdecomp)[9]$test$sigma[1]
  regression[1,10] <- summary(effdecomp)[9]$test$sigma[2]
  regression[1,4] <- summary(effdecomp)[9]$test$sigma[3]
  regression[1,8] <- summary(effdecomp)[9]$test$pvalues[1]
  regression[1,11] <- summary(effdecomp)[9]$test$pvalues[2]
  regression[1,5] <- summary(effdecomp)[9]$test$pvalues[3]
  regression[1,12] <- regression[1,9]/regression[1,3]
  regression[1,13] <- "Primary"
  regression[1,14] <- "6m to 12m"
  
  mediation_effects <- rbind(mediation_effects, regression)
}

mediation_effects_primary_6mto12m_GlycA <- mediation_effects



###### hsCRP

mediation_effects <-  data.frame(mediator=character(),
                                 biomarkerid=character(),
                                 total_estimate=double(),
                                 total_se=double(),
                                 total_p=double(),
                                 direct_estimate=double(),
                                 direct_se=double(),
                                 direct_p=double(),
                                 indirect_estimate=double(),
                                 indirect_se=double(),
                                 indirect_p=double(),
                                 mediation=double(),
                                 model=character(),
                                 time=character(),
                                 stringsAsFactors=FALSE)
regression <- mediation_effects

df_mediation_data <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$hscrp),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$anyinfection4wk12mo),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$age_interview_m12),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$gender),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$z_scores_birth),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$hhincome),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$bfany),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$mth12collectiontostorage),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$anympsmoke),]
df_mediation_data <- df_mediation_data[!is.na(df_mediation_data$gestage),]

metabs <- c("total_DE", "total_C1P", "total_THC", "total_LPC_P", "total_PE_O", "total_PE_P", "total_CE", "HexCer(d18:2/18:0)", 
            "HexCer(d18:2/22:0)", "Hex3Cer(d18:1/18:0)", "Hex3Cer(d18:1/20:0)", "Hex3Cer(d18:1/22:0)", 
            "GM3(d18:1/18:0)", "DE(18:2)", "CE(22:6)", "HexCer(d16:1/24:0)", "PE(18:0_20:3) (a)")

for(i in metabs){
  
  
  df_mediation_loop <- df_mediation_data[!is.na(df_mediation_data[[i]]),]
  df_mediation_loop[[i]] <- log(df_mediation_loop[[i]])   
  df_mediation_loop[[i]] <- as.numeric(scale(df_mediation_loop[[i]]))
  
  
  expData <- neImpute(paste0("`",i,"` ~ anyinfection4wk12mo + hscrp + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage"), family = gaussian(link = "identity"), data = df_mediation_loop, nRep = 5)
  neMod1 <- neModel(paste0("`",i,"` ~ anyinfection4wk12mo0 + anyinfection4wk12mo1 + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage"), family = gaussian(link = "identity"), expData = expData, se = "robust")
  
  effdecomp <- neEffdecomp(neMod1)
  
  regression[1,1] <- "hsCRP"
  regression[1,2] <- paste(i)
  regression[1,6] <- summary(effdecomp)[9]$test$coefficients[1]
  regression[1,9] <- summary(effdecomp)[9]$test$coefficients[2]
  regression[1,3] <- summary(effdecomp)[9]$test$coefficients[3]
  regression[1,7] <- summary(effdecomp)[9]$test$sigma[1]
  regression[1,10] <- summary(effdecomp)[9]$test$sigma[2]
  regression[1,4] <- summary(effdecomp)[9]$test$sigma[3]
  regression[1,8] <- summary(effdecomp)[9]$test$pvalues[1]
  regression[1,11] <- summary(effdecomp)[9]$test$pvalues[2]
  regression[1,5] <- summary(effdecomp)[9]$test$pvalues[3]
  regression[1,12] <- regression[1,9]/regression[1,3]
  regression[1,13] <- "Primary"
  regression[1,14] <- "Birth to 12m"
  
  mediation_effects <- rbind(mediation_effects, regression)
}

mediation_effects_primary_bto12m_hsCRP <- mediation_effects

######### Metabolomics mediation - 6m to 12m


mediation_effects <-  data.frame(mediator=character(),
                                 biomarkerid=character(),
                                 total_estimate=double(),
                                 total_se=double(),
                                 total_p=double(),
                                 direct_estimate=double(),
                                 direct_se=double(),
                                 direct_p=double(),
                                 indirect_estimate=double(),
                                 indirect_se=double(),
                                 indirect_p=double(),
                                 mediation=double(),
                                 model=character(),
                                 time=character(),
                                 stringsAsFactors=FALSE)
regression <- mediation_effects

df_mediation_data_6mto12m <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$hscrp),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$anyinfection4wk12mo),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$age_interview_m12),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$gender),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$z_scores_birth),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$hhincome),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$bfany),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$mth12collectiontostorage),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$anympsmoke),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$gestage),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$anyinfection4wk6mo),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$anyinfection9mo12mo),]
df_mediation_data_6mto12m <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m$hsCRP_6m),]


colnames(df_mediation_data_6mto12m) <- make.names(colnames(df_mediation_data_6mto12m), unique=TRUE)

metabs <- c("total_DE", "total_C1P", "total_THC", "total_LPC_P", "total_PE_O", "total_PE_P", "total_CE", "HexCer.d18.2.18.0.", 
            "HexCer.d18.2.22.0.", "Hex3Cer.d18.1.18.0.", "Hex3Cer.d18.1.20.0.",  "Hex3Cer.d18.1.22.0.", 
            "GM3.d18.1.18.0.", "DE.18.2.", "CE.22.6.", "HexCer.d16.1.24.0.", "PE.18.0_20.3...a.")

for(i in metabs){
  
  
  j <- paste0(i,"_6m")
  df_mediation_loop <- df_mediation_data_6mto12m[!is.na(df_mediation_data_6mto12m[[i]]),]
  df_mediation_loop[[i]] <- log(df_mediation_loop[[i]])   
  df_mediation_loop[[i]] <- as.numeric(scale(df_mediation_loop[[i]]))
  df_mediation_loop <- df_mediation_loop[!is.na(df_mediation_loop[[j]]),]
  df_mediation_loop[[j]] <- log(df_mediation_loop[[j]])   
  df_mediation_loop[[j]] <- as.numeric(scale(df_mediation_loop[[j]]))
  
  expData <- neImpute(paste0("`",i,"` ~ anyinfection9mo12mo + hscrp + anyinfection4wk6mo + hsCRP_6m + ",j," + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage"), family = gaussian(link = "identity"), data = df_mediation_loop, nRep = 5)
  neMod1 <- neModel(paste0("`",i,"` ~ anyinfection9mo12mo0 + anyinfection9mo12mo1 + anyinfection4wk6mo + hsCRP_6m + ",j," + age_interview_m12 + gender + z_scores_birth + hhincome + bfany + mth12collectiontostorage + anympsmoke + gestage"), family = gaussian(link = "identity"), expData = expData, se = "robust")
  
  effdecomp <- neEffdecomp(neMod1)
  
  regression[1,1] <- "hsCRP"
  regression[1,2] <- paste(i)
  regression[1,6] <- summary(effdecomp)[9]$test$coefficients[1]
  regression[1,9] <- summary(effdecomp)[9]$test$coefficients[2]
  regression[1,3] <- summary(effdecomp)[9]$test$coefficients[3]
  regression[1,7] <- summary(effdecomp)[9]$test$sigma[1]
  regression[1,10] <- summary(effdecomp)[9]$test$sigma[2]
  regression[1,4] <- summary(effdecomp)[9]$test$sigma[3]
  regression[1,8] <- summary(effdecomp)[9]$test$pvalues[1]
  regression[1,11] <- summary(effdecomp)[9]$test$pvalues[2]
  regression[1,5] <- summary(effdecomp)[9]$test$pvalues[3]
  regression[1,12] <- regression[1,9]/regression[1,3]
  regression[1,13] <- "Primary"
  regression[1,14] <- "6m to 12m"
  
  mediation_effects <- rbind(mediation_effects, regression)
}

mediation_effects_primary_6mto12m_hsCRP <- mediation_effects

mediation_results <- rbind(mediation_effects_primary_bto12m_GlycA, mediation_effects_primary_bto12m_hsCRP, 
                           mediation_effects_primary_6mto12m_GlycA, mediation_effects_primary_6mto12m_hsCRP)

write.csv(mediation_results, 'BIS_eLife_Fig7_SourceData_1_2_LSMC.csv')




####### Mediation plot - Figure 7 and figure supplement 1 ####### 


mediation_results_plot <- rbind(mediation_effects_primary_bto12m_GlycA, mediation_effects_primary_bto12m_hsCRP, 
                                mediation_effects_primary_6mto12m_GlycA, mediation_effects_primary_6mto12m_hsCRP)

mediation_results_plot$biomarkerid[mediation_results_plot$biomarkerid=="HexCer.d18.2.18.0."] <- "HexCer(d18:2/18:0)"
mediation_results_plot$biomarkerid[mediation_results_plot$biomarkerid=="HexCer.d18.2.22.0."] <- "HexCer(d18:2/22:0)"
mediation_results_plot$biomarkerid[mediation_results_plot$biomarkerid=="Hex3Cer.d18.1.18.0."] <- "Hex3Cer(d18:1/18:0)"
mediation_results_plot$biomarkerid[mediation_results_plot$biomarkerid=="Hex3Cer.d18.1.20.0."] <- "Hex3Cer(d18:1/20:0)"
mediation_results_plot$biomarkerid[mediation_results_plot$biomarkerid=="Hex3Cer.d18.1.22.0."] <- "Hex3Cer(d18:1/22:0)"
mediation_results_plot$biomarkerid[mediation_results_plot$biomarkerid=="GM3.d18.1.18.0."] <- "GM3(d18:1/18:0)"
mediation_results_plot$biomarkerid[mediation_results_plot$biomarkerid=="DE.18.2."] <- "DE(18:2)"
mediation_results_plot$biomarkerid[mediation_results_plot$biomarkerid=="CE.22.6."] <- "CE(22:6)"
mediation_results_plot$biomarkerid[mediation_results_plot$biomarkerid=="HexCer.d16.1.24.0."] <- "HexCer(d16:1/24:0)"
mediation_results_plot$biomarkerid[mediation_results_plot$biomarkerid=="PE.18.0_20.3...a."] <- "PE(18:0_20:3) (a)"


mediation_results_plot_totals <- mediation_results_plot[c(1:7,18:24,35:41,52:58),]
mediation_results_plot_species <- mediation_results_plot[c(8:17,25:34,42:51,59:68),]

df_to_plot_totals <-
  mediation_results_plot_totals %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 


df_to_plot_totals <- na.omit(df_to_plot_totals)

df_to_plot_base <- df_to_plot_totals[df_to_plot_totals$time=="Birth to 12m",]

mediation_plot <-  data.frame(name=character(),
                              estimate=double(),
                              se=double(),
                              pvalue=double(),
                              mediator=character(),
                              effect=character(),
                              group=character(),
                              stringsAsFactors=FALSE)

regression <- mediation_plot

for(i in 1:nrow(df_to_plot_base)){
  
  regression[1:3,1] <- df_to_plot_base[i, 15]
  regression[1:3,5] <- df_to_plot_base[i, 1]
  regression[1:3,7] <- "LC/MS lipidomics class totals"
  regression[1,6] <- "Indirect effect"
  regression[2,6] <- "Direct effect"
  regression[3,6] <- "Total effect"
  regression[1,2] <- df_to_plot_base[i,9]
  regression[1,3] <- df_to_plot_base[i,10]
  regression[1,4] <- df_to_plot_base[i,11]
  regression[2,2] <- df_to_plot_base[i,6]
  regression[2,3] <- df_to_plot_base[i,7]
  regression[2,4] <- df_to_plot_base[i,8]
  regression[3,2] <- df_to_plot_base[i,3]
  regression[3,3] <- df_to_plot_base[i,4]
  regression[3,4] <- df_to_plot_base[i,5]
  
  
  mediation_plot <- rbind(mediation_plot, regression)
}

mediation_plot_totals <- mediation_plot



mediation_results_plot_species$name <-  mediation_results_plot_species$biomarkerid

df_to_plot_base_species <- mediation_results_plot_species[mediation_results_plot_species$time=="Birth to 12m",]

mediation_plot <-  data.frame(name=character(),
                              estimate=double(),
                              se=double(),
                              pvalue=double(),
                              mediator=character(),
                              effect=character(),
                              group=character(),
                              stringsAsFactors=FALSE)

regression <- mediation_plot

for(i in 1:nrow(df_to_plot_base_species)){
  
  regression[1:3,1] <- df_to_plot_base_species[i, 15]
  regression[1:3,5] <- df_to_plot_base_species[i, 1]
  regression[1:3,7] <- "Lipid species"
  regression[1,6] <- "Indirect effect"
  regression[2,6] <- "Direct effect"
  regression[3,6] <- "Total effect"
  regression[1,2] <- df_to_plot_base_species[i,9]
  regression[1,3] <- df_to_plot_base_species[i,10]
  regression[1,4] <- df_to_plot_base_species[i,11]
  regression[2,2] <- df_to_plot_base_species[i,6]
  regression[2,3] <- df_to_plot_base_species[i,7]
  regression[2,4] <- df_to_plot_base_species[i,8]
  regression[3,2] <- df_to_plot_base_species[i,3]
  regression[3,3] <- df_to_plot_base_species[i,4]
  regression[3,4] <- df_to_plot_base_species[i,5]
  
  
  mediation_plot <- rbind(mediation_plot, regression)
}

mediation_plot_species <- mediation_plot

mediation_plot <- rbind(mediation_plot_totals, mediation_plot_species)

mediation_plot_trim <- mediation_plot[(mediation_plot$mediator!="hsCRP") | (mediation_plot$effect!="Total effect"),]

mediation_plot_trim$mediator[mediation_plot_trim$effect=="Total effect"] <- "Total effect"
mediation_plot_trim <- mediation_plot_trim[mediation_plot_trim$effect!="Direct effect",]
mediation_plot_trim$mediator[mediation_plot_trim$mediator=="GlycA"] <- "GlycA indirect effect"
mediation_plot_trim$mediator[mediation_plot_trim$mediator=="hsCRP"] <- "hsCRP indirect effect"

mediation_plot_trim$mediator <- as.factor(mediation_plot_trim$mediator)
mediation_plot_trim$mediator <- factor(mediation_plot_trim$mediator,levels(mediation_plot_trim$mediator)[c(2,1,3)])


ggplot_multi <-
  mediation_plot_trim %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue,
        psignif = 0.05,
        shape = mediator,
        colour = mediator,
        xlab = "Total effect of infections from birth to 12 months of age on 12-month biomarkers\nand indirect effects mediated by 12-month GlycA or hsCRP",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.1, 0.1)) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8))
      + ggplot2::scale_shape_manual(values = c(23L, 22L, 21L))
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = c(6, 10)
)

ggsave("Figures/BIS_eLife_Fig7_LCMS.png", width=8, height=8)




###### 6m to 12m mediation plot


df_to_plot_base <- df_to_plot_totals[df_to_plot_totals$time=="6m to 12m",]

mediation_plot <-  data.frame(name=character(),
                              estimate=double(),
                              se=double(),
                              pvalue=double(),
                              mediator=character(),
                              effect=character(),
                              group=character(),
                              stringsAsFactors=FALSE)

regression <- mediation_plot

for(i in 1:nrow(df_to_plot_base)){
  
  regression[1:3,1] <- df_to_plot_base[i, 15]
  regression[1:3,5] <- df_to_plot_base[i, 1]
  regression[1:3,7] <- "LC/MS lipidomics class totals"
  regression[1,6] <- "Indirect effect"
  regression[2,6] <- "Direct effect"
  regression[3,6] <- "Total effect"
  regression[1,2] <- df_to_plot_base[i,9]
  regression[1,3] <- df_to_plot_base[i,10]
  regression[1,4] <- df_to_plot_base[i,11]
  regression[2,2] <- df_to_plot_base[i,6]
  regression[2,3] <- df_to_plot_base[i,7]
  regression[2,4] <- df_to_plot_base[i,8]
  regression[3,2] <- df_to_plot_base[i,3]
  regression[3,3] <- df_to_plot_base[i,4]
  regression[3,4] <- df_to_plot_base[i,5]
  
  
  mediation_plot <- rbind(mediation_plot, regression)
}

mediation_plot_totals <- mediation_plot





df_to_plot_base_species <- mediation_results_plot_species[mediation_results_plot_species$time=="6m to 12m",]

mediation_plot <-  data.frame(name=character(),
                              estimate=double(),
                              se=double(),
                              pvalue=double(),
                              mediator=character(),
                              effect=character(),
                              group=character(),
                              stringsAsFactors=FALSE)

regression <- mediation_plot

for(i in 1:nrow(df_to_plot_base_species)){
  
  regression[1:3,1] <- df_to_plot_base_species[i, 15]
  regression[1:3,5] <- df_to_plot_base_species[i, 1]
  regression[1:3,7] <- "Lipid species"
  regression[1,6] <- "Indirect effect"
  regression[2,6] <- "Direct effect"
  regression[3,6] <- "Total effect"
  regression[1,2] <- df_to_plot_base_species[i,9]
  regression[1,3] <- df_to_plot_base_species[i,10]
  regression[1,4] <- df_to_plot_base_species[i,11]
  regression[2,2] <- df_to_plot_base_species[i,6]
  regression[2,3] <- df_to_plot_base_species[i,7]
  regression[2,4] <- df_to_plot_base_species[i,8]
  regression[3,2] <- df_to_plot_base_species[i,3]
  regression[3,3] <- df_to_plot_base_species[i,4]
  regression[3,4] <- df_to_plot_base_species[i,5]
  
  
  mediation_plot <- rbind(mediation_plot, regression)
}

mediation_plot_species <- mediation_plot

mediation_plot <- rbind(mediation_plot_totals, mediation_plot_species)

mediation_plot_trim <- mediation_plot[(mediation_plot$mediator!="hsCRP") | (mediation_plot$effect!="Total effect"),]

mediation_plot_trim$mediator[mediation_plot_trim$effect=="Total effect"] <- "Total effect"
mediation_plot_trim <- mediation_plot_trim[mediation_plot_trim$effect!="Direct effect",]
mediation_plot_trim$mediator[mediation_plot_trim$mediator=="GlycA"] <- "GlycA indirect effect"
mediation_plot_trim$mediator[mediation_plot_trim$mediator=="hsCRP"] <- "hsCRP indirect effect"

mediation_plot_trim$mediator <- as.factor(mediation_plot_trim$mediator)
mediation_plot_trim$mediator <- factor(mediation_plot_trim$mediator,levels(mediation_plot_trim$mediator)[c(2,1,3)])


ggplot_multi <-
  mediation_plot_trim %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue,
        psignif = 0.05,
        shape = mediator,
        colour = mediator,
        xlab = "Total effect of infections from 6 to 12 months of age on 12-month biomarkers\nand indirect effects mediated by 12-month GlycA or hsCRP\nadjusted for infections birth to 6-month, 6-month biomarkers, and 6-month GlycA or hsCRP",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.12, 0.12)) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8))
      + ggplot2::scale_shape_manual(values = c(23L, 22L, 21L))
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = c(6, 10)
)

ggsave("Figures/BIS_eLife_Fig7_FigSupp1_LCMS.png", width=8, height=8)



#### Reverse causality model - Birth lipidomics predicting birth to 6m infections - Supp. File 3B ####

# Read the biomarker concentration file
df_nmr_results <- readr::read_csv(
  # Enter the correct location for your file below
  file = "Data/BIS_infection_dataset_LCMS.csv",
  # Set not only NA but TAG string as <NA> 
  na = c("NA", "TAG")
)


df_nmr_results_birth <- df_nmr_results[(df_nmr_results$timepoint=="Birth"),]

df_nmr_results_alt_names <- df_nmr_results_birth

nmr_biomarkers <- names(df_nmr_results_alt_names %>% select("Sph(d16:1)":"total_OxSpecies"))

LSMC.minimumvalues <- data.frame(metabolite=character(),
                                 minimum=double(),
                                 stringsAsFactors=FALSE) 
holder <- LSMC.minimumvalues

for(i in nmr_biomarkers){
  
  holder[1,1] <- paste(i)
  holder[1,2] <- min(df_nmr_results_alt_names[[i]][!!df_nmr_results_alt_names[[i]]], na.rm=TRUE)
  
  LSMC.minimumvalues <- rbind(LSMC.minimumvalues, holder)
  df_nmr_results_alt_names[[i]] <- df_nmr_results_alt_names[[i]]+holder[1,2]
  
}

marker_names <- read_csv("lipid_name_conversion.csv")

df_nmr_results_alt_names$anyinfection4wk6mo <- df_nmr_results_alt_names$anyinfection4wk + df_nmr_results_alt_names$anyinfection3mo + df_nmr_results_alt_names$anyinfection6mo
df_nmr_results_alt_names$anyinfection9mo12mo <- df_nmr_results_alt_names$anyinfection9mo + df_nmr_results_alt_names$anyinfection12mo


df_nmr_results_alt_names_infectiondataonly <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$anyinfection4wk12mo), ]

# Encoding mode of delivery
df_nmr_results_alt_names_infectiondataonly$modebirth_3[df_nmr_results_alt_names_infectiondataonly$modebirth==1] <- 1
df_nmr_results_alt_names_infectiondataonly$modebirth_3[df_nmr_results_alt_names_infectiondataonly$modebirth==2] <- 1
df_nmr_results_alt_names_infectiondataonly$modebirth_3[df_nmr_results_alt_names_infectiondataonly$modebirth==3] <- 1
df_nmr_results_alt_names_infectiondataonly$modebirth_3[df_nmr_results_alt_names_infectiondataonly$modebirth==4] <- 2
df_nmr_results_alt_names_infectiondataonly$modebirth_3[df_nmr_results_alt_names_infectiondataonly$modebirth==5] <- 3



birthlipid_infections <- data.frame(estimate=double(),
                                    se=double(),
                                    p.value=double(),
                                    pvalue_adj=double(),
                                    biomarkerid=character(),
                                    stringsAsFactors=FALSE)
regression <- birthlipid_infections

for(i in nmr_biomarkers){
  df_nmr_results_alt_names_infectiondataonly[,paste("",i,"", sep="")] <- log(df_nmr_results_alt_names_infectiondataonly[,paste("",i,"", sep="")])
  df_nmr_results_alt_names_infectiondataonly[,paste("",i,"", sep="")] <- as.numeric(scale(df_nmr_results_alt_names_infectiondataonly[,paste("",i,"", sep="")]))
  df_regression <- glm(as.formula(paste("anyinfection4wk6mo ~ `",i,"` + age_interview_m6 + gender + z_scores_birth + hhincome + bfany + gestage + anympsmoke + factor(modebirth_3)", sep="")), family = quasipoisson(link = "log"), data=df_nmr_results_alt_names_infectiondataonly)
  
  regression[1,1] <- coef(summary(df_regression))[2, 1]
  regression[1,2] <- coef(summary(df_regression))[2, 2]
  regression[1,3:4] <- coef(summary(df_regression))[2, 4]
  regression[1,5] <- paste("",i,"", sep="")
  
  birthlipid_infections <- rbind(birthlipid_infections, regression)
}



df_assoc_per_biomarker_bmi_totalsonly <- birthlipid_infections[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue_adj, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:5]


df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


ggplot_multi <-
  df_linear %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue_adj,
        psignif = 0.05,
        xlab = "Difference in number of reported infections from birth to 6 months\nper 1 SD change in log metabolite at birth",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.2, 0.2)) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8))
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = ggplot_multi$rel_heights
)

ggsave("Figures/BIS_eLife_SuppFile3B.png", width=4, height=6)


#### Reverse causality model - 6m lipids predicting 6mo to 12mo infections - Supp File 3D ####


df_nmr_results_6m <- df_nmr_results[(df_nmr_results$timepoint=="6 months"),]

df_nmr_results_6m_completecase <- df_nmr_results_6m[!is.na(df_nmr_results_6m$anyinfection4wk12mo),]

df_nmr_results_alt_names_6m <- df_nmr_results_6m_completecase

LCMS.minimumvalues <- data.frame(metabolite=character(),
                                 minimum=double(),
                                 stringsAsFactors=FALSE) 
holder <- LCMS.minimumvalues


for(i in nmr_biomarkers){
  
  holder[1,1] <- paste(i)
  holder[1,2] <- min(df_nmr_results_alt_names_6m[[i]][!!df_nmr_results_alt_names_6m[[i]]], na.rm=TRUE)
  
  LCMS.minimumvalues <- rbind(LCMS.minimumvalues, holder)
  df_nmr_results_alt_names_6m[[i]] <- df_nmr_results_alt_names_6m[[i]]+holder[1,2]
  
}



df_6m_lipids <- df_nmr_results_alt_names_6m %>% select("bisid", "Sph(d16:1)":"total_OxSpecies")


df_nmr_results_alt_names_6m$anyinfection4wk6mo <- df_nmr_results_alt_names_6m$anyinfection4wk + df_nmr_results_alt_names_6m$anyinfection3mo + df_nmr_results_alt_names_6m$anyinfection6mo
df_nmr_results_alt_names_6m$anyinfection9mo12mo <- df_nmr_results_alt_names_6m$anyinfection9mo + df_nmr_results_alt_names_6m$anyinfection12mo


df_nmr_results_alt_names_infectiondataonly <- df_nmr_results_alt_names_6m[!is.na(df_nmr_results_alt_names_6m$anyinfection4wk12mo), ]



birthlipid_infections <- data.frame(estimate=double(),
                                    se=double(),
                                    p.value=double(),
                                    pvalue_adj=double(),
                                    biomarkerid=character(),
                                    stringsAsFactors=FALSE)
regression <- birthlipid_infections

for(i in nmr_biomarkers){
  df_nmr_results_alt_names_infectiondataonly[,paste("",i,"", sep="")] <- log(df_nmr_results_alt_names_infectiondataonly[,paste("",i,"", sep="")])
  df_nmr_results_alt_names_infectiondataonly[,paste("",i,"", sep="")] <- as.numeric(scale(df_nmr_results_alt_names_infectiondataonly[,paste("",i,"", sep="")]))
  df_regression <- glm(as.formula(paste("anyinfection9mo12mo ~ `",i,"` + anyinfection4wk6mo + age_interview_m12 + gender + z_scores_birth + hhincome + mth6CollectiontoStorage_hr + bfany + gestage + anympsmoke", sep="")), family = quasipoisson(link = "log"), data=df_nmr_results_alt_names_infectiondataonly)
  
  regression[1,1] <- coef(summary(df_regression))[2, 1]
  regression[1,2] <- coef(summary(df_regression))[2, 2]
  regression[1,3:4] <- coef(summary(df_regression))[2, 4]
  regression[1,5] <- paste("",i,"", sep="")
  
  birthlipid_infections <- rbind(birthlipid_infections, regression)
}



df_assoc_per_biomarker_bmi_totalsonly <- birthlipid_infections[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue_adj, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:5]


df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


ggplot_multi <-
  df_linear %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue_adj,
        psignif = 0.05,
        xlab = "Difference in number of reported infections from 6 to 12 months\nper 1 SD change in log metabolite at 6 months",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.2, 0.2)) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8))
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = ggplot_multi$rel_heights
)

ggsave("Figures/BIS_eLife_SuppFile3D.png", width=4, height=6)


########## Models with 6-month lipidomics as outcome - Figure 5-figure supplement 2, and Figure 6-figure supplement 2 ########

beta.comparison.MS <- data.frame(metabolite=character(815),
                                 infection.beta=double(815),
                                 glyca.beta=double(815),
                                 hscrp.beta=double(815),
                                 stringsAsFactors=FALSE) 

########### Infection as exposure - Figure 5-figure supplement 2 ########


# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, anyinfection4wk6mo, age_interview_m6, gender, z_scores_birth, hhincome, bfany, mth6CollectiontoStorage_hr, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ anyinfection4wk6mo + age_interview_m6 + gender + z_scores_birth + hhincome + bfany + mth6CollectiontoStorage_hr + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = anyinfection4wk6mo
  )

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

beta.comparison.MS$metabolite <- df_assoc_per_biomarker_bmi$biomarkerid
beta.comparison.MS$infection.beta <- df_assoc_per_biomarker_bmi$estimate

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


ggplot_multi <-
  df_linear %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue,
        psignif = 0.05,
        xlab = "Difference in 6-month log lipids (SD units) for each infection from birth to 6 months",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.15, 0.15)) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8))
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = ggplot_multi$rel_heights
)

ggsave("Figures/BIS_eLife_Fig5_FigSupp2A.png", width=4, height=6)



df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]
df_assoc_per_biomarker_bmi_species <- df_assoc_per_biomarker_bmi[1:776,]
df_assoc_per_biomarker_bmi_species$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_species$pvalue, method = "BH")
df_assoc_per_biomarker_bmi_totalsonly$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_combinedplot <- rbind(df_assoc_per_biomarker_bmi_species, df_assoc_per_biomarker_bmi_totalsonly)

lipid_results <- df_assoc_per_biomarker_bmi_combinedplot

lipid_results$coef <- lipid_results$estimate
lipid_results$coef_lower <- lipid_results$estimate - (1.96 * lipid_results$se)
lipid_results$coef_upper <- lipid_results$estimate + (1.96 * lipid_results$se)
lipid_results$pval <- lipid_results$pvalue
lipid_results$qval <- lipid_results$pvalue_adj

lipid_results <- as.data.frame(lipid_results[,c(1,6:10)])  

write.csv(lipid_results,"BIS_eLife_Fig5_SourceData2A.csv")



###### Bootstrapping ############
df_nmr_results_alt_names_infection <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$anyinfection4wk12mo),]


library(boot)

set.seed(12345)


bootstrap_bca_cis <-  data.frame(biomarkerid=character(),
                                 estimate=double(),
                                 l.ci=double(),
                                 u.ci=double(),
                                 stringsAsFactors=FALSE)
regression <- bootstrap_bca_cis

for(i in nmr_biomarkers[-815]){
  
  df_nmr_results_alt_names_infection[[i]] <- log(df_nmr_results_alt_names_infection[[i]])
  df_nmr_results_alt_names_infection[[i]] <- as.numeric(scale(df_nmr_results_alt_names_infection[[i]]))
  
  boot.huber <- function(data, indices, maxit=20){
    data <- data[indices,] # select obs. in bootstrap sample
    mod <- lm(as.formula(paste("`",i,"` ~ anyinfection4wk6mo + age_interview_m6 + gender + z_scores_birth + hhincome + bfany + mth6CollectiontoStorage_hr + anympsmoke + gestage", sep = "")), data=data, maxit=maxit)
    coefficients(mod) # return coefficient vector
  }
  
  
  duncan.boot <- boot(df_nmr_results_alt_names_infection, boot.huber, 1000, maxit=100)

  ci_boot_bca <- boot.ci(duncan.boot, index=2, type="bca")
  
  regression[1,1] <- paste(i)
  regression[1,2] <- mean(duncan.boot$t[,2])
  regression[1,3] <- ci_boot_bca$bca[4]
  regression[1,4] <- ci_boot_bca$bca[5]
  
  bootstrap_bca_cis <- rbind(bootstrap_bca_cis, regression)
  
}

bootstrap_infection_lipids_bfany <- bootstrap_bca_cis
write.csv(bootstrap_infection_lipids_bfany, "BIS_eLife_Figure5_SourceData2A_bootstrap.csv")



########### Markers of inflammation ########


df_nmr_results_alt_names$gp_exposure <- log(df_nmr_results_alt_names$GlycA_6m)
df_nmr_results_alt_names$gp_exposure <- as.numeric(scale(df_nmr_results_alt_names$gp_exposure))

df_nmr_results_alt_names$hscrp_exposure <- log(df_nmr_results_alt_names$hsCRP_6m)
df_nmr_results_alt_names$hscrp_exposure <- as.numeric(scale(df_nmr_results_alt_names$hscrp_exposure))



#### GlycA - Figure 5-figure supplement 2B ######

df_nmr_results_alt_names_trimmed <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$anyinfection4wk6mo), ]

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_trimmed %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, gp_exposure, age_interview_m6, gender, z_scores_birth, hhincome, bfany, mth6CollectiontoStorage_hr, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ gp_exposure + age_interview_m6 + gender + z_scores_birth + hhincome + bfany + mth6CollectiontoStorage_hr + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = gp_exposure
  ) 

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

beta.comparison.MS$glyca.beta <- df_assoc_per_biomarker_bmi$estimate

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


ggplot_multi <-
  df_linear %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue,
        psignif = 0.05,
        xlab = "Difference in 6-month log lipids (SD units) per 1 SD higher 6-month log GlycA",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.5, 0.5)) +
        ggplot2::scale_shape_manual(
          values = c(22L),
          labels = c("GlycA")) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8)) +
        ggplot2::theme(legend.position = "none")
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = ggplot_multi$rel_heights
)

ggsave("Figures/BIS_eLife_Fig5_FigSupp2B.png", width=4, height=6)


df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]
df_assoc_per_biomarker_bmi_species <- df_assoc_per_biomarker_bmi[1:776,]
df_assoc_per_biomarker_bmi_species$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_species$pvalue, method = "BH")
df_assoc_per_biomarker_bmi_totalsonly$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_combinedplot <- rbind(df_assoc_per_biomarker_bmi_species, df_assoc_per_biomarker_bmi_totalsonly)

lipid_results <- df_assoc_per_biomarker_bmi_combinedplot

lipid_results$coef <- lipid_results$estimate
lipid_results$coef_lower <- lipid_results$estimate - (1.96 * lipid_results$se)
lipid_results$coef_upper <- lipid_results$estimate + (1.96 * lipid_results$se)
lipid_results$pval <- lipid_results$pvalue
lipid_results$qval <- lipid_results$pvalue_adj

lipid_results <- as.data.frame(lipid_results[,c(1,6:10)])  

write.csv(lipid_results,"BIS_eLife_Fig5_SourceData2B.csv")


###### Bootstrapping ############
df_nmr_results_alt_names_infection <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$anyinfection4wk12mo),]


library(boot)

set.seed(12345)


bootstrap_bca_cis <-  data.frame(biomarkerid=character(),
                                 estimate=double(),
                                 l.ci=double(),
                                 u.ci=double(),
                                 stringsAsFactors=FALSE)
regression <- bootstrap_bca_cis

for(i in nmr_biomarkers[-815]){
  
  df_nmr_results_alt_names_infection[[i]] <- log(df_nmr_results_alt_names_infection[[i]])
  df_nmr_results_alt_names_infection[[i]] <- as.numeric(scale(df_nmr_results_alt_names_infection[[i]]))
  
  boot.huber <- function(data, indices, maxit=20){
    data <- data[indices,] # select obs. in bootstrap sample
    mod <- lm(as.formula(paste("`",i,"` ~ gp_exposure + age_interview_m6 + gender + z_scores_birth + hhincome + bfany + mth6CollectiontoStorage_hr + anympsmoke + gestage", sep = "")), data=data, maxit=maxit)
    coefficients(mod) # return coefficient vector
  }
  
  
  duncan.boot <- boot(df_nmr_results_alt_names_infection, boot.huber, 1000, maxit=100)

  ci_boot_bca <- boot.ci(duncan.boot, index=2, type="bca")
  
  regression[1,1] <- paste(i)
  regression[1,2] <- mean(duncan.boot$t[,2])
  regression[1,3] <- ci_boot_bca$bca[4]
  regression[1,4] <- ci_boot_bca$bca[5]
  
  bootstrap_bca_cis <- rbind(bootstrap_bca_cis, regression)
  
}

bootstrap_GlycA_lipids_bfany <- bootstrap_bca_cis
write.csv(bootstrap_GlycA_lipids_bfany, "BIS_eLife_Figure5_SourceData2B_bootstrap.csv")




#### hsCRP - Figure 6-figure supplement 2A  ######

df_nmr_results_alt_names_trimmed <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$anyinfection4wk6mo), ]

# Select only variables to be used for the model and collapse to a long data 
# format
df_long <-
  df_nmr_results_alt_names_trimmed %>%
  # Select only model variables
  dplyr::select(nmr_biomarkers, hscrp_exposure, age_interview_m6, gender, z_scores_birth, hhincome, bfany, mth6CollectiontoStorage_hr, anympsmoke, gestage) %>%
  # log-tranform biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(log(.))) %>%
  # Scale biomarkers
  dplyr::mutate_at(.vars = c(nmr_biomarkers), .funs = dplyr::funs(as.numeric(scale(.)))) %>%
  # Collapse to a long data format
  tidyr::gather(key = biomarkerid, value = biomarkervalue, nmr_biomarkers)

df_long <- na.omit(df_long)

# Estimate sex- and age-adjusted associations of metabolite to BMI
df_assoc_per_biomarker_bmi <-
  ggforestplot::discovery_regression(
    df_long = df_long,
    model = "lm",
    formula =
      formula(
        biomarkervalue ~ hscrp_exposure + age_interview_m6 + gender + z_scores_birth + hhincome + bfany + mth6CollectiontoStorage_hr + anympsmoke + gestage
      ),
    key = biomarkerid,
    predictor = hscrp_exposure
  ) 

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]

df_assoc_per_biomarker_bmi_totalsonly$pvalue <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi_totalsonly[1:4]

beta.comparison.MS$hscrp.beta <- df_assoc_per_biomarker_bmi$estimate

df_to_plot <-
  df_assoc_per_biomarker_bmi_totalsonly %>%
  # use right_join, with df_grouping on the right, to preserve the order of 
  # biomarkers it specifies. 
  dplyr::right_join(., marker_names, by = "biomarkerid") 

df_to_plot <- na.omit(df_to_plot)

df_to_plot <- df_to_plot %>%
  arrange(match(group, c("Sphingolipids", "Glycero-phospholipids", "Alkyl-phospholipids", "Plasmalogens", "Sterols", "Glycerolipids")))

df_linear <- df_to_plot[1:32,]

df_linear$rownumber = 1:nrow(df_linear)

df_linear <-
  df_linear %>%
  dplyr::arrange(rownumber)


ggplot_multi <-
  df_linear %>%
  nest(-group, .key = "data") %>%
  # Apply forestplot to each group
  mutate(
    gg_groups = purrr::map2(
      data, group, ~ forestplot(
        df = .x,
        pvalue = pvalue,
        psignif = 0.05,
        xlab = "Difference in 6-month log lipids (SD units) per 1 SD higher 6-month log hsCRP",
        title = .y,
      ) +
        ggplot2::coord_cartesian(xlim = c(-0.5, 0.5)) +
        ggplot2::scale_shape_manual(
          values = c(23L),
          labels = c("hsCRP")) + ggplot2::scale_color_brewer(palette="Dark2") + ggplot2::theme(plot.title = element_text(size=9), axis.title.x=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8),  legend.text=element_text(size=8)) +
        ggplot2::theme(legend.position = "none")
    ),
    # Optional: remove x-axis and legend for all plots except the bottom one
    gg_groups = ifelse(
      test = row_number() != n(),
      yes =
        purrr::map(gg_groups, ~ . +
                     theme(
                       axis.text.x = element_blank(),
                       axis.title.x = element_blank(),
                       axis.ticks.x = element_blank(),
                       plot.margin = unit(c(1, 2, 1, 2), "mm")
                     ) +
                     ggplot2::theme(legend.position = "none")),
      no = gg_groups
    ),
    rel_heights = purrr::map(
      data,  ~ nrow(.)
    ) %>% unlist()
  )

patchwork::wrap_plots(
  ggplot_multi$gg_groups,
  ncol = 1,
  heights = ggplot_multi$rel_heights
)

ggsave("Figures/BIS_eLife_Fig6_FigSupp2A.png", width=4, height=6)


df_assoc_per_biomarker_bmi_totalsonly <- df_assoc_per_biomarker_bmi[777:815,]
df_assoc_per_biomarker_bmi_species <- df_assoc_per_biomarker_bmi[1:776,]
df_assoc_per_biomarker_bmi_species$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_species$pvalue, method = "BH")
df_assoc_per_biomarker_bmi_totalsonly$pvalue_adj <- p.adjust(df_assoc_per_biomarker_bmi_totalsonly$pvalue, method = "BH")

df_assoc_per_biomarker_bmi_combinedplot <- rbind(df_assoc_per_biomarker_bmi_species, df_assoc_per_biomarker_bmi_totalsonly)

lipid_results <- df_assoc_per_biomarker_bmi_combinedplot

lipid_results$coef <- lipid_results$estimate
lipid_results$coef_lower <- lipid_results$estimate - (1.96 * lipid_results$se)
lipid_results$coef_upper <- lipid_results$estimate + (1.96 * lipid_results$se)
lipid_results$pval <- lipid_results$pvalue
lipid_results$qval <- lipid_results$pvalue_adj

lipid_results <- as.data.frame(lipid_results[,c(1,6:10)])  

write.csv(lipid_results,"Results/BIS_eLife_Fig6_SourceData2.csv")

# Continue main code




###### Bootstrapping ############
df_nmr_results_alt_names_infection <- df_nmr_results_alt_names[!is.na(df_nmr_results_alt_names$anyinfection4wk12mo),]


library(boot)

set.seed(12345)


bootstrap_bca_cis <-  data.frame(biomarkerid=character(),
                                 estimate=double(),
                                 l.ci=double(),
                                 u.ci=double(),
                                 stringsAsFactors=FALSE)
regression <- bootstrap_bca_cis

for(i in nmr_biomarkers[-815]){
  
  df_nmr_results_alt_names_infection[[i]] <- log(df_nmr_results_alt_names_infection[[i]])
  df_nmr_results_alt_names_infection[[i]] <- as.numeric(scale(df_nmr_results_alt_names_infection[[i]]))
  
  boot.huber <- function(data, indices, maxit=20){
    data <- data[indices,] # select obs. in bootstrap sample
    mod <- lm(as.formula(paste("`",i,"` ~ hscrp_exposure + age_interview_m6 + gender + z_scores_birth + hhincome + bfany + mth6CollectiontoStorage_hr + anympsmoke + gestage", sep = "")), data=data, maxit=maxit)
    coefficients(mod) # return coefficient vector
  }
  
  
  duncan.boot <- boot(df_nmr_results_alt_names_infection, boot.huber, 1000, maxit=100)

  ci_boot_bca <- boot.ci(duncan.boot, index=2, type="bca")
  
  regression[1,1] <- paste(i)
  regression[1,2] <- mean(duncan.boot$t[,2])
  regression[1,3] <- ci_boot_bca$bca[4]
  regression[1,4] <- ci_boot_bca$bca[5]
  
  bootstrap_bca_cis <- rbind(bootstrap_bca_cis, regression)
  
}

bootstrap_hsCRP_lipids_bfany <- bootstrap_bca_cis
write.csv(bootstrap_hsCRP_lipids_bfany, "BIS_eLife_Figure6_SourceData2_bootstrap.csv")



###### Scatterplot of 6-month lipidomic difference correlation - Figure 5-fig supp 2C, 6-fig supp 2B, 6-fig supp 2C #####


# Add the regression line without the confidence interval
q <- ggplot(beta.comparison.MS, aes(x=infection.beta, y=glyca.beta)) +
  geom_point(shape=15, color="darkgrey")+
  geom_smooth(method=lm, se=FALSE, color="black")+
  theme_classic()+
  labs(x="Infection Beta (per 1 infection)", y = "GlycA Beta (per SD log GlycA)")

ggsave(plot = q, width = 3, height = 3, dpi = 600, filename = "Figures/BIS_eLife_Figure5_FigSupp2C.png")

cor.test(beta.comparison.MS$infection.beta, beta.comparison.MS$glyca.beta)

q <- ggplot(beta.comparison.MS, aes(x=infection.beta, y=hscrp.beta)) +
  geom_point(shape=18, color="darkgrey")+
  geom_smooth(method=lm, se=FALSE, color="black")+
  theme_classic()+
  labs(x="Infection Beta (per 1 infection)", y = "hsCRP Beta (per SD log hsCRP)")

ggsave(plot = q, width = 3, height = 3, dpi = 600, filename = "Figures/BIS_eLife_Figure6_FigSupp2B.png")


cor.test(beta.comparison.MS$infection.beta, beta.comparison.MS$hscrp.beta)

q <- ggplot(beta.comparison.MS, aes(x=glyca.beta, y=hscrp.beta)) +
  geom_point(shape=18, color="darkgrey")+
  geom_smooth(method=lm, se=FALSE, color="black")+
  theme_classic()+
  labs(x="GlycA Beta (per SD log GlycA)", y = "hsCRP Beta (per SD log hsCRP)")

ggsave(plot = q, width = 3, height = 3, dpi = 600, filename = "Figures/BIS_eLife_Figure6_FigSupp2C.png")


cor.test(beta.comparison.MS$glyca.beta, beta.comparison.MS$hscrp.beta)
